<?xml version="1.0" encoding="UTF-8"?>

<!-- Actuators.xslt
Description:
This file contains actuator specific templates for generating actuator related outputs with XSLT.

Notes:
This file is compatible with the msxml / msxsl 4.0 XML parser and transform tools.

History:
2002-07-03 		Original																																			R. Trent Garverick
2002-08-28		Added ActuatorName Template																											RTG
2002-10-22		Modified actuator names per R. Elfrink e-mail	
				Modified ActuatorName template to use actuator name variables instead of hardcode numbers 			RTG
2002-12-06		Added ActuatorOther variable
2003-10-22		Added SteamPlusProfiler, GenericAC800, GenericOPC and VoithOPCDilution actuator types			MPK
2004-04-21		Added CoatWeightProfiler and SmartCoatWeightProfiler types and corrected Induction spelling		RTG
2004-07-29		Added Falcon Actuator Types																											MPK
2004-08-12		Added CoatPlus Profiler and renamed FalconSlice and Falcon Dilution to SlicePlus and FlowPlus  	DMC
2006-08-14     	Added Induction xP Profiler Types																										LC
2008-06-04		Integrated MCD: changed node assignment for actuator interface		AZ
2011-01-19		Added Dilution_xP_II_Profiler, Slice_xP_II_Profiler, and CoatWeight_xP_II_Profiler actuator types			MPK
2013-10-17		Added support for Induction xP II Actuators				AD

-->

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" exclude-result-prefixes="rs z" xmlns:rs="urn:schemas-microsoft-com:rowset" xmlns:z="#RowsetSchema">
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	
	<!-- 	
	*********************************************************************************************************************
		Quality Control System Actuator Types
	*********************************************************************************************************************
	-->
	
	<xsl:variable name="SliceProfiler" select="1"/>
	<xsl:variable name="SmartWeightProfiler" select="2"/>
	<xsl:variable name="SmartCalenderProfiler" select="3"/>
	<xsl:variable name="DilutionProfiler" select="5"/>
	<xsl:variable name="SmartConsistencyProfiler" select="7"/>
	<xsl:variable name="AccuRaySerialWeight" select="8"/>
	<xsl:variable name="AccuRaySerialCaliper" select="9"/>
	<xsl:variable name="AccuRaySerialMoisture" select="10"/>
	<xsl:variable name="ImpactIRSerial" select="11"/>
	<xsl:variable name="ImpactThermajetSerial" select="12"/>
	<xsl:variable name="ImpactStepperMotorsSerial" select="13"/>
	<xsl:variable name="MX200100SerialThermatrol" select="14"/>
	<xsl:variable name="MX200100SerialDynatrol" select="15"/>
	<xsl:variable name="MX200100SerialCaltrol" select="16"/>
	<xsl:variable name="MX200100SerialAquatrol" select="17"/>
	<xsl:variable name="VIBSerialSteambox" select="18"/>
	<xsl:variable name="SteamPlusProfiler" select="19"/>
	<xsl:variable name="GenericAC800" select="20"/>
	<xsl:variable name="GenericOPC" select="21"/>
	<xsl:variable name="VoithOPCDilution" select="22"/>
	<xsl:variable name="InductionProfiler" select="23"/>
	<xsl:variable name="CoatWeightProfiler" select="24"/>
	<xsl:variable name="SmartCoatWeightProfiler" select="25"/>
	<xsl:variable name="AirWatersprayProfiler" select="26"/>
	<xsl:variable name="Dilution_xP_Profiler" select="27"/>
	<xsl:variable name="Slice_xP_Profiler" select="28"/>
	<xsl:variable name="CoatWeight_xP_Profiler" select="29"/>
	<xsl:variable name="Induction_xP_Profiler" select="30"/>
	<xsl:variable name="Dilution_xP_II_Profiler" select="31"/>
	<xsl:variable name="Slice_xP_II_Profiler" select="32"/>
	<xsl:variable name="CoatWeight_xP_II_Profiler" select="33"/>
	<xsl:variable name="Induction_xP_II_Profiler" select="34"/>
	<xsl:variable name="Induction_xP_Plus" select="35"/>
	<xsl:variable name="Calcoil" select="36"/>
	<xsl:variable name="Devronizer" select="37"/>
	<xsl:variable name="ProCoat" select="38"/>
	<xsl:variable name="ProFlowII" select="39"/>
	<xsl:variable name="Aqualizer" select="40"/>
	<xsl:variable name="ActuatorOther" select="9999"/>
	<!-- The following variable is left to avoid breaking applications that used it prior to the addition of the above ActuatorOther variable -->
	<xsl:variable name="Other" select="9999"/>


	<xsl:template name="ActuatorName">
		<xsl:param name="ActuatorType"/>
		<xsl:choose>
			<xsl:when test="$ActuatorType=$SliceProfiler"><xsl:text>SliceProfiler</xsl:text></xsl:when>	
			<xsl:when test="$ActuatorType=$SmartWeightProfiler"><xsl:text>SmartWeightProfiler</xsl:text></xsl:when>						
			<xsl:when test="$ActuatorType=$SmartCalenderProfiler"><xsl:text>SmartCalenderProfiler</xsl:text></xsl:when>						
			<xsl:when test="$ActuatorType=$CoatWeightProfiler"><xsl:text>CoatWeightProfiler</xsl:text></xsl:when>					
			<xsl:when test="$ActuatorType=$DilutionProfiler"><xsl:text>DilutionProfiler</xsl:text></xsl:when>						
			<xsl:when test="$ActuatorType=$SmartCoatWeightProfiler"><xsl:text>SmartCoatWeightProfiler</xsl:text></xsl:when>					
			<xsl:when test="$ActuatorType=$SmartConsistencyProfiler"><xsl:text>SmartConsistencyProfiler</xsl:text></xsl:when>
			<xsl:when test="$ActuatorType=$AccuRaySerialWeight"><xsl:text>AccuRaySerialWeight</xsl:text></xsl:when>						
			<xsl:when test="$ActuatorType=$AccuRaySerialCaliper"><xsl:text>AccuRaySerialCaliper</xsl:text></xsl:when>
			<xsl:when test="$ActuatorType=$AccuRaySerialMoisture"><xsl:text>AccuRaySerialMoisture</xsl:text></xsl:when>						
			<xsl:when test="$ActuatorType=$ImpactIRSerial"><xsl:text>ImpactIRAccuRaySerial</xsl:text></xsl:when>					
			<xsl:when test="$ActuatorType=$ImpactThermajetSerial"><xsl:text>ImpactThermajetAccuRaySerial</xsl:text></xsl:when>	
			<xsl:when test="$ActuatorType=$ImpactStepperMotorsSerial"><xsl:text>ImpactStepperMotorAccuRaySerial</xsl:text></xsl:when>				
			<xsl:when test="$ActuatorType=$MX200100SerialThermatrol"><xsl:text>MXThermatrol200100Serial</xsl:text></xsl:when>					
			<xsl:when test="$ActuatorType=$MX200100SerialDynatrol"><xsl:text>MXDynatrol200100Serial</xsl:text></xsl:when>					
			<xsl:when test="$ActuatorType=$MX200100SerialCaltrol"><xsl:text>MXCaltrol200100Serial</xsl:text>	</xsl:when>		
			<xsl:when test="$ActuatorType=$MX200100SerialAquatrol"><xsl:text>MXAquatrol200100Serial</xsl:text></xsl:when>
			<xsl:when test="$ActuatorType=$VIBSerialSteambox"><xsl:text>VIBSteamboxAsciiSerial</xsl:text></xsl:when>						
			<xsl:when test="$ActuatorType=$SteamPlusProfiler"><xsl:text>SteamPlusProfiler</xsl:text></xsl:when>						
			<xsl:when test="$ActuatorType=$GenericAC800"><xsl:text>GenericAC800</xsl:text></xsl:when>						
			<xsl:when test="$ActuatorType=$GenericOPC"><xsl:text>GenericOPC</xsl:text></xsl:when>						
			<xsl:when test="$ActuatorType=$VoithOPCDilution"><xsl:text>VoithOPCDilution</xsl:text></xsl:when>						
			<xsl:when test="$ActuatorType=$InductionProfiler"><xsl:text>InductionProfiler</xsl:text></xsl:when>						
			<xsl:when test="$ActuatorType=$CoatWeightProfiler"><xsl:text>CoatWeightProfiler</xsl:text></xsl:when>						
			<xsl:when test="$ActuatorType=$SmartCoatWeightProfiler"><xsl:text>SmartCoatWeightProfiler</xsl:text></xsl:when>
			<xsl:when test="$ActuatorType=$AirWatersprayProfiler"><xsl:text>AirWatersprayProfiler</xsl:text></xsl:when>						
			<xsl:when test="$ActuatorType=$Dilution_xP_Profiler"><xsl:text>Dilution xP Profiler</xsl:text></xsl:when>
			<xsl:when test="$ActuatorType=$Slice_xP_Profiler"><xsl:text>Slice xP Profiler</xsl:text></xsl:when>
			<xsl:when test="$ActuatorType=$CoatWeight_xP_Profiler"><xsl:text>CoatWeight xP Profiler</xsl:text></xsl:when>	
			<xsl:when test="$ActuatorType=$Induction_xP_Profiler"><xsl:text>Induction xP Profiler</xsl:text></xsl:when>			
			<xsl:when test="$ActuatorType=$Dilution_xP_II_Profiler"><xsl:text>Dilution xP Profiler</xsl:text></xsl:when>
			<xsl:when test="$ActuatorType=$Slice_xP_II_Profiler"><xsl:text>Slice xP Profiler</xsl:text></xsl:when>
			<xsl:when test="$ActuatorType=$CoatWeight_xP_II_Profiler"><xsl:text>CoatWeight xP Profiler</xsl:text></xsl:when>
			<xsl:when test="$ActuatorType=$Induction_xP_Plus"><xsl:text>Induction xP Plus Profiler</xsl:text></xsl:when>
			<xsl:when test="$ActuatorType=$Induction_xP_II_Profiler"><xsl:text>Induction xP Profiler</xsl:text></xsl:when>
			<xsl:when test="$ActuatorType=$Calcoil"><xsl:text>GenericOPC</xsl:text></xsl:when>
			<xsl:when test="$ActuatorType=$Devronizer"><xsl:text>GenericOPC</xsl:text></xsl:when>
			<xsl:when test="$ActuatorType=$ProCoat"><xsl:text>GenericOPC</xsl:text></xsl:when>
			<xsl:when test="$ActuatorType=$ProFlowII"><xsl:text>GenericOPC</xsl:text></xsl:when>
			<xsl:when test="$ActuatorType=$Aqualizer"><xsl:text>GenericOPC</xsl:text></xsl:when>
			<xsl:when test="$ActuatorType=$ActuatorOther"><xsl:text>Other</xsl:text></xsl:when>			
		</xsl:choose>
	</xsl:template>
		
	<!-- 
	Template to determine the node name the actuator interface for a given actuator based on its ActuatorID
	Rules:
		1) If actuator is controlled by standard CD then put on same node as standard CD.
		2) If actuator is only controlled by MCD then put on MCD node.
		3) If actuator is not controlled then put on main QCS node.
	-->
	<xsl:template name="ActuatorNodeName">
		<xsl:param name="ActuatorID"/>
		<xsl:for-each select="//z:row/tblActuators[@ActuatorID=$ActuatorID]">
			<xsl:variable name="ActName" select="@oName"/>
			<xsl:variable name="NumActuators" select="@NumberZones"/>
			<xsl:variable name="ActuatorTypeName" select="@ActuatorTypeName"/>
			<!-- determine the node id for the actuator -->
			<xsl:variable name="ActNodeID">
				<xsl:choose>
					<!-- if actuator is controlled by classic CD control it should be on the same node as the controller -->
					<xsl:when test="tblClassicCDControls">
						<xsl:value-of select="tblClassicCDControls/@Node"/>
					</xsl:when>
					<!-- if actuator is controlled by MCD but not by classic CD it should be on the MCD node -->
					<xsl:when test="not(tblClassicCDControls) and //tblHMCActsbyHMC/tblHMCActuators[@HMCActuator=$ActuatorID]">
						<xsl:value-of select="//tblHMCActsbyHMC[./tblHMCActuators/@HMCActuator=$ActuatorID]/@HMCNode"/>
					</xsl:when>
					<!-- otherwise the actuator should be on the main QCS node -->
					<xsl:otherwise>
						<xsl:value-of select="//tblNodes[@NodeType=$MainNode]/@NodeID"/>
					</xsl:otherwise>
				</xsl:choose>					
			</xsl:variable>
			<!-- determine the node name for the actuator -->
			<xsl:value-of select="//tblNodes[@NodeID=$ActNodeID]/@NodeName"/>
		</xsl:for-each>
	</xsl:template>

</xsl:stylesheet>
