<?xml version="1.0" encoding="UTF-8"?>
<!-- ConfigReport.xslt
Description:
This file is used to generate the html job order configuration report.

Notes:
This file is compatible with the msxml / msxsl 4.0 XML SP1 parser and transform tools.

History:
2002-10-16 		Original															R. Trent Garverick
2003-01-02		Added weight and ash target entry modes						RTG
2004-03-23	       Added Aspect Server node to general section					RTG
2004-08-18		Added Level1 Motors section									MPK
2004-08-18		Added Color Controls section									MPK
2004-11-25		Added new fields to the General section							MPK
2007-05-02		Fixed bug for System 800xA Target					AD
2007-01-23		Added processing for PlatformBaseline41R5d				PJL
2007-08-09		Added processing for AC800M Connect version instead of platform version   			PJL
2008-06-04		Integrated MCD: added infos for MCD, SoftMEas, CD Switch		AZ
2008-06-16		Removed SoftMeas		AZ
2008-06-24		Fixed MCD node name		AZ
2011-03-08		Removed references to AC800 Connect version					PJL
2022-07-18		Added External MD Measurements										PT
	
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:rs="urn:schemas-microsoft-com:rowset" xmlns:z="#RowsetSchema" xmlns:abb="http://www.abb.com/AutomationTechnologyProducts" xmlns:ms="urn:schemas-microsoft-com:xslt">
	<!-- 
	******************************************************
	Imports
	******************************************************		
	-->
	<xsl:import href="NodeTypes.xslt"/>
	<xsl:import href="Globals.xslt"/>
	<xsl:import href="MDControl.xslt"/>
	<xsl:import href="Actuators.xslt"/>
	<xsl:output method="html" version="1.0" encoding="UTF-8" indent="yes"/>
	<xsl:strip-space elements="*"/>
	<xsl:variable name="colWidthp75" select="75"/>
	<xsl:variable name="colWidth1" select="100"/>
	<xsl:variable name="colWidth1p5" select="150"/>
	<xsl:variable name="colWidth2" select="200"/>
	<xsl:variable name="colWidth3" select="300"/>
	<xsl:variable name="colWidth4" select="400"/>
	<xsl:variable name="colWidth5" select="500"/>
	<xsl:variable name="colWidth6" select="600"/>
	<xsl:variable name="bg1" select="'#B0C4DE'"/>
	<xsl:variable name="bg2" select="'white'"/>
	<xsl:template match="//z:row">
		<h1>ABB Quality Control QCS800xA - Job Order Configuration Report</h1>
		<br/>

		<h5>General Section</h5>
		<table>
			<tbody>
				<tr bgcolor="{$bg1}">
					<td width="{$colWidth4}">
						<b>Job Order</b>
					</td>
					<td>
						<xsl:value-of select="@JobOrder"/>
					</td>
				</tr>
				<tr bgcolor="{$bg2}">
					<td width="{$colWidth4}">
						<b>Time/Date Generated</b>
					</td>
					<td>
						<xsl:value-of select="abb:GetCurrentTime()"/>
					</td>
				</tr>
				<tr bgcolor="{$bg2}">
					<td width="{$colWidth4}">
						<b>Machine</b>
					</td>
					<td>
						<xsl:value-of select="@MachineName"/>
					</td>
				</tr>
				<tr bgcolor="{$bg1}">
					<td width="{$colWidth4}">
						<b>Quality Control Connectivity Server</b>
					</td>
					<td>
						<xsl:value-of select="$MainNodeName"/>
					</td>
				</tr>
				<xsl:if test="//tblNodes[@NodeType=$CDNode]">
					<tr bgcolor="{$bg2}">
						<td width="{$colWidth4}">
							<b>Secondary Quality Control Connectivity Server</b>
						</td>
						<td>
							<xsl:value-of select="$SecondaryNodeName"/>
						</td>
					</tr>
				</xsl:if>
				<xsl:for-each select="//tblNodes[@NodeType=$MCDNode]">
					<tr bgcolor="{$bg2}">
						<td width="{$colWidth4}">
							<b>MCD Connectivity Server</b>
						</td>
						<td>
							<xsl:value-of select="@NodeName"/>
						</td>
					</tr>
				</xsl:for-each>
				<tr bgcolor="{$bg2}">
					<td width="{$colWidth4}">
						<b>AC800M Connectivity Server</b>
					</td>
					<td>
						<xsl:value-of select="$AC800MNode"/>
					</td>
				</tr>
				<tr bgcolor="{$bg1}">
					<td width="{$colWidth4}">
						<b>Aspect Server</b>
					</td>
					<td>
            <xsl:variable name="PPASvrNodeID" select="//z:row/@PPA"/>
            <xsl:value-of select="//tblNodes[@NodeID=$PPASvrNodeID]/@NodeName"/>
          </td>
				</tr>
				<xsl:if test="$ColorControlExists='true'">
					<tr bgcolor="{$bg2}">
						<td width="{$colWidth4}">
							<b>Color Control Server</b>
						</td>
						<td>
							<xsl:value-of select="$ColorControlNode"/>
						</td>
					</tr>
					<tr bgcolor="{$bg1}">
						<td width="{$colWidth4}">
							<b>Color Control Simulation Server</b>
						</td>
						<td>
							<xsl:value-of select="$ColorControlSimNode"/>
						</td>
					</tr>
				</xsl:if>
				<tr bgcolor="{$bg2}">
					<td width="{$colWidth4}">
						<b>Machine Type</b>
					</td>
					<td>
						<xsl:call-template name="GetMDMachineTypeName">
							<xsl:with-param name="MachineTypeID">
								<xsl:value-of select="@MachineType"/>
							</xsl:with-param>
						</xsl:call-template>
					</td>
				</tr>
				<tr bgcolor="{$bg2}">
					<td width="{$colWidth4}">
						<b>Units</b>
					</td>
					<td>
						<xsl:call-template name="GetUnitsTypeName">
							<xsl:with-param name="UnitsTypeID">
								<xsl:value-of select="@Units"/>
							</xsl:with-param>
						</xsl:call-template>
					</td>
				</tr>
				<tr bgcolor="{$bg2}">
					<td width="{$colWidth4}">
						<b>Ream Size</b>
					</td>
					<td>
						<xsl:value-of select="@ReamSize"/>
					</td>
				</tr>
				<tr bgcolor="{$bg2}">
					<td width="{$colWidth4}">
						<b># Shifts</b>
					</td>
					<td>
						<xsl:value-of select="@NumberShifts"/>
					</td>
				</tr>
				<xsl:if test="@NumberShifts &gt;0">
					<tr bgcolor="{$bg2}">
						<td width="{$colWidth4}">
							<b>Shift 1 Time</b>
						</td>
						<td>
							<xsl:value-of select="ms:format-time(@Shift1Time, 'HH:mm:ss')"/>
						</td>
					</tr>
				</xsl:if>
				<xsl:if test="@NumberShifts &gt;1">
					<tr bgcolor="{$bg2}">
						<td width="{$colWidth4}">
							<b>Shift 2 Time</b>
						</td>
						<td>
							<xsl:value-of select="ms:format-time(@Shift2Time, 'HH:mm:ss')"/>
						</td>
					</tr>
				</xsl:if>
				<xsl:if test="@NumberShifts &gt;2">
					<tr bgcolor="{$bg2}">
						<td width="{$colWidth4}">
							<b>Shift 3 Time</b>
						</td>
						<td>
							<xsl:value-of select="ms:format-time(@Shift3Time, 'HH:mm:ss')"/>
						</td>
					</tr>
				</xsl:if>
				<xsl:if test="@NumberShifts &gt;3">
					<tr bgcolor="{$bg2}">
						<td width="{$colWidth4}">
							<b>Shift 4 Time</b>
						</td>
						<td>
							<xsl:value-of select="ms:format-time(@Shift4Time, 'HH:mm:ss')"/>
						</td>
					</tr>
				</xsl:if>
				<tr bgcolor="{$bg2}">
					<td width="{$colWidth4}">
						<b>Conditioned Weight Factor</b>
					</td>
					<td>
						<xsl:value-of select="format-number(@CondWtFactor, '#.0')"/>
					</td>
				</tr>
				<tr bgcolor="{$bg2}">
					<td width="{$colWidth4}">
						<b>Front-Back Orientation</b>
					</td>
					<xsl:choose>
						<xsl:when test="/xml/rs:data/z:row/@FrontBackOrientation=$ORI_BackFront">
							<td>Back-Front</td>
						</xsl:when>
						<xsl:when test="/xml/rs:data/z:row/@FrontBackOrientation=$ORI_FrontBack">
							<td>Front-Back</td>
						</xsl:when>
					</xsl:choose>
				</tr>
			</tbody>
		</table>
		<br/>
		<br/>
		<h2>Scanners and Measurements</h2>
		<table class="qcsrpt">
			<tbody>
				<xsl:for-each select="//z:row/tblScanners">
					<tr bgcolor="{$bg1}">
						<th align="left">Scanner</th>
						<th align="left">Description</th>
						<th align="left">IP Address</th>
						<th align="left">Databoxes</th>
						<th align="left">MD Position</th>
						<th align="left">Orientation</th>
<!--						<th align="left">Spd Chg Delay</th> -->
						<th align="left">Measurements</th>
					</tr>
					<tr bgcolor="{$bg2}">
						<td width="{$colWidth1}" valign="top">
							<xsl:value-of select="concat('Frame ', @oNum)"/>
						</td>
						<td width="{$colWidth1}" valign="top">
							<xsl:value-of select="@Description"/>
						</td>
						<td width="{$colWidth1}" valign="top">
							<xsl:value-of select="@ScannerIPAddress"/>
						</td>
						<td width="{$colWidth1}" valign="top">
							<xsl:value-of select="@NumDataBoxes"/>
						</td>
						<td width="{$colWidth1}" valign="top">
							<xsl:value-of select="@MDReferencePosition"/>
						</td>
						<td width="{$colWidth1}" valign="top">
							<xsl:choose>
								<xsl:when test="$ORI_DB1atFront">DB1 at Front</xsl:when>
								<xsl:when test="$ORI_DB1atBack">DB1 at Back</xsl:when>
							</xsl:choose>
						</td>
						<!--<td width="{$colWidth1}" valign="top">
							<xsl:value-of select="@SpeedChangeDelay"/>
						</td>-->
						<td>
							<table>
								<tbody>
									<tr>
										<th align="left">Type</th>
										<th align="left">Description</th>
										<th align="left">Estimation</th>
										<th align="left">Nickname</th>
										<th align="left">Single Profile</th>
										<th align="left">Composite Profile</th>
										<th align="left">Mapped Profile</th>
										<th align="left">Historize Profile</th>
										<th align="left">VPA Source</th>
										<xsl:if test="./tblMeasurements[@MeasurementTypeID=$CalcMeas]">
											<th align="left">Contributing Measurements</th>
										</xsl:if>
									</tr>
									<xsl:for-each select="./tblMeasurements">
										<xsl:variable name="mname">
											<xsl:call-template name="MeasName">
												<xsl:with-param name="SensorType">
													<xsl:value-of select="@SensorType"/>
												</xsl:with-param>
												<xsl:with-param name="MeasurementType">
													<xsl:value-of select="@MeasurementTypeID"/>
												</xsl:with-param>
											</xsl:call-template>
										</xsl:variable>
										<xsl:variable name="senstype" select="@SensorType"/>
										<tr>
											<td width="{$colWidth3}" valign="top">
												<xsl:value-of select="$mname"/>
											</td>
											<td width="{$colWidth3}" valign="top">
												<xsl:value-of select="@Description"/>
											</td>
											<xsl:variable name="ctrlName">
												<xsl:choose>
													<xsl:when test="//tblControlledMeasurements/tblMeasurements[@MeasurementID=current()/@MeasurementID]">
														<xsl:value-of select="@MeasName"/>
													</xsl:when>
													<xsl:otherwise/>
												</xsl:choose>
											</xsl:variable>
											<td width="{$colWidth1}" valign="top">
												<xsl:value-of select="$ctrlName"/>
											</td>
											<xsl:variable name="num" select="count(preceding-sibling::*[(@MeasurementTypeID = current()/@MeasurementTypeID) and (../@ScannerID = current()/@ScannerID)]) + 1"/>
											<!-- measurement nickname (WT1, MO1, ...) -->
											<xsl:variable name="nickname">
												<xsl:call-template name="SP_Nickname">
													<xsl:with-param name="SensorType">
														<xsl:value-of select="@SensorType"/>
													</xsl:with-param>
													<xsl:with-param name="MeasurementType">
														<xsl:value-of select="@MeasurementTypeID"/>
													</xsl:with-param>
													<xsl:with-param name="MeasurementNumber">
														<xsl:value-of select="$num"/>
													</xsl:with-param>
												</xsl:call-template>
											</xsl:variable>
											<td width="{$colWidth1}" valign="top">
												<xsl:value-of select="$nickname"/>
											</td>
											<td width="{$colWidth1}" valign="top">
												<xsl:value-of select="@SingleScanProfile"/>
											</td>
											<td width="{$colWidth1}" valign="top">
												<xsl:value-of select="@CompositeProfile"/>
											</td>
											<td width="{$colWidth1}" valign="top">
												<xsl:value-of select="@MapProfileSize"/>
											</td>
											<td width="{$colWidth1}" valign="top">
												<xsl:value-of select="@HistorizeProfile"/>
											</td>
											<td width="{$colWidth1}" valign="top">
												<xsl:value-of select="@VPASource"/>
											</td>
											<xsl:if test="@MeasurementTypeID=$CalcMeas">
												<td width="{$colWidth6}" valign="top">
													<table>
														<tbody>
															<tr>
																<th>Description</th>
																<th>Measurement</th>
															</tr>
															<xsl:for-each select="./tblContributingMeasurements">
																<tr>
																	<td width="{$colWidth3}" valign="top">
																		<xsl:value-of select="@Description"/>
																	</td>
																	<td width="{$colWidth3}" valign="top">
																		<xsl:variable name="contmeasid" select="@ContribMeasurementID"/>
																		<xsl:value-of select="//tblMeasurements[@MeasurementID=$contmeasid]/@Description"/>
																	</td>
																</tr>
															</xsl:for-each>
														</tbody>
													</table>
												</td>
											</xsl:if>
										</tr>
									</xsl:for-each>
								</tbody>
							</table>
						</td>
					</tr>
				</xsl:for-each>
			</tbody>
		</table>
		<br/>
		<br/>
		<h2>MD Control</h2>
		<table>
			<tbody>
				<tr bgcolor="{$bg1}">
					<td width="{$colWidth2}">
						<b>Weight Target Entry</b>
					</td>
					<td>
						<xsl:value-of select="$WTModeString"/>
					</td>
				</tr>
				<tr bgcolor="{$bg2}">
					<td width="{$colWidth2}">
						<b>Ash Target Entry</b>
					</td>
					<td>
						<xsl:value-of select="$AshModeString"/>
					</td>
				</tr>
			</tbody>
		</table>
		<h3>Advanced Controls</h3>
		<table>
			<tbody>
				<tr bgcolor="{$bg1}">
					<td width="{$colWidth2}">
						<b>Auto Grade Change</b>
					</td>
					<td>
						<xsl:value-of select="//tblAdvancedControls/@AGC"/>
					</td>
				</tr>
				<tr bgcolor="{$bg2}">
					<td width="{$colWidth2}">
						<b>Dryer</b>
					</td>
					<td>
						<xsl:value-of select="//tblAdvancedControls/@Dryer"/>
					</td>
				</tr>
				<tr bgcolor="{$bg1}">
					<td width="{$colWidth2}">
						<b>Drystock</b>
					</td>
					<td>
						<xsl:value-of select="//tblAdvancedControls/@Drystock"/>
					</td>
				</tr>
				<tr bgcolor="{$bg2}">
					<td width="{$colWidth2}">
						<b>Headbox</b>
					</td>
					<td>
						<xsl:value-of select="//tblAdvancedControls/@Headbox"/>
					</td>
				</tr>
				<tr bgcolor="{$bg2}">
					<td width="{$colWidth2}">
						<b>Consisteny Compensation</b>
					</td>
					<td>
						<xsl:value-of select="//tblAdvancedControls/@ConsistencyCompensation"/>
					</td>
				</tr>
				<tr bgcolor="{$bg1}">
					<td width="{$colWidth2}">
						<b>Speed</b>
					</td>
					<td>
						<xsl:value-of select="//tblAdvancedControls/@Speed"/>
					</td>
				</tr>
				<tr bgcolor="{$bg1}">
					<td width="{$colWidth2}">
						<b>Speed Optimization</b>
					</td>
					<td>
						<xsl:value-of select="//tblAdvancedControls/@SpeedOpt"/>
					</td>
				</tr>
				<tr bgcolor="{$bg1}">
					<td width="{$colWidth2}">
						<b>Dryer Limited Speed Optimization</b>
					</td>
					<td>
						<xsl:value-of select="//tblAdvancedControls/@DryerLimitedSpeedOpt"/>
					</td>
				</tr>
			</tbody>
		</table>
		<h3>Scan Level Controls</h3>
		<table>
			<tbody>
				<tr bgcolor="{$bg1}">
					<th align="left">Type</th>
					<th align="left">Name</th>
					<th align="left">Actuator</th>
					<th align="left">Measurement</th>
					<th align="left">MFIC Upstream Ref</th>
				</tr>
				<xsl:for-each select="//z:row/tblScanLevelControls">
					<xsl:variable name="mdType">
						<xsl:call-template name="MD_Nickname">
							<xsl:with-param name="Name" select="@Name"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:variable name="actName">
						<xsl:call-template name="GetL1">
							<xsl:with-param name="Name" select="@Name"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:variable name="measName">
						<xsl:choose>
							<xsl:when test="@MeasurementID >100">
								<xsl:value-of select="//tblMeasurements[@MeasurementID=current()/@MeasurementID]/@MeasName"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="//tblExtMDMeasurements[@ExtMDMeasID=current()/@MeasurementID]/@ExtMDMeasName"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<tr bgcolor="{$bg2}">
						<td width="{$colWidth2}" valign="top">
							<xsl:value-of select="$mdType"/>
						</td>
						<td width="{$colWidth1}" valign="top">
							<xsl:value-of select="@Name"/>
						</td>
						<td width="{$colWidth1}" valign="top">
							<xsl:value-of select="$actName"/>
						</td>
						<td width="{$colWidth1}" valign="top">
							<xsl:value-of select="$measName"/>
						</td>
						<td width="{$colWidth2}" valign="top">
							<xsl:value-of select="@MFICUpStreamLoop"/>
						</td>
					</tr>
				</xsl:for-each>
			</tbody>
		</table>
		<xsl:if test="//tblAdvancedControls/@Speed='True'">
			<h3>Speed Control</h3>
			<xsl:variable name="actName" select="//tblLevel1Controls[@Level1ID=//tblSpeedControls/@Level1Control]/@ActuatorName"/>
			<table>
				<tbody>
					<tr bgcolor="{$bg1}">
						<th align="left">Name</th>
						<th align="left">Actuator</th>
					</tr>
					<tr bgcolor="{$bg2}">
						<td width="{$colWidth1}" valign="top">
							<xsl:value-of select="//tblSpeedControls/@Name"/>
						</td>
						<td width="{$colWidth1}" valign="top">
							<xsl:value-of select="$actName"/>
						</td>
					</tr>
				</tbody>
			</table>
		</xsl:if>
		<xsl:if test="//tblAdvancedControls/@Headbox='True'">
			<h3>Headbox Control(s)</h3>
			<table>
				<tbody>
					<tr bgcolor="{$bg1}">
						<th align="left">Name</th>
						<th align="left">Actuator</th>
						<th align="left">Wire Speed</th>
						<th align="left">Dryline Actuator</th>
						<th align="left">Jet Velocity Mode</th>
					</tr>
					<xsl:for-each select="//tblLevel1Controls/tblHeadboxControls">
						<xsl:variable name="x" select="./@Level1Control"/>
						<xsl:variable name="y" select="./@OptDryline"/>
						<xsl:variable name="actName" select="//tblLevel1Controls[@Level1ID=$x]/@ActuatorName"/>
						<xsl:variable name="optDLName" select="//tblLevel1Controls[@Level1ID=$y]/@ActuatorName"/>
						<xsl:variable name="jvMode">
							<xsl:call-template name="GetJetVelocityMode">
								<xsl:with-param name="mode" select="./@JetVelocityMode"/>
							</xsl:call-template>
						</xsl:variable>
						<tr bgcolor="{$bg2}">
							<td width="{$colWidth1}" valign="top">
								<xsl:value-of select="./@Name"/>
							</td>
							<td width="{$colWidth1}" valign="top">
								<xsl:value-of select="$actName"/>
							</td>
							<td width="{$colWidth1}" valign="top">
								<xsl:value-of select="./@WireSpeedName"/>
							</td>
							<td width="{$colWidth2}" valign="top">
								<xsl:value-of select="$optDLName"/>
							</td>
							<td width="{$colWidth2}" valign="top">
								<xsl:value-of select="$jvMode"/>
							</td>
						</tr>
					</xsl:for-each>
				</tbody>
			</table>
		</xsl:if>
		<br/>
		<br/>
		<h2>Level 1 Controls and Measurements</h2>
		<h3>Level 1 Controls</h3>
		<table>
			<tbody>
				<tr bgcolor="{$bg1}">
					<th align="left">Actuator</th>
					<th align="left">Type</th>
					<th align="left">Description</th>
					<th align="left">Output Type</th>
					<th align="left">TagName</th>
				</tr>
				<xsl:for-each select="//z:row/tblLevel1Controls">
					<xsl:variable name="L1Type">
						<xsl:call-template name="GetL1TypeName">
							<xsl:with-param name="Level1ID" select="@Level1ID"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:variable name="outType">
						<xsl:call-template name="GetL1OutputTypeName">
							<xsl:with-param name="Level1ID" select="@Level1ID"/>
						</xsl:call-template>
					</xsl:variable>
					<tr bgcolor="{$bg2}">
						<td width="{$colWidth1}" valign="top">
							<xsl:value-of select="@ActuatorName"/>
						</td>
						<td width="{$colWidth1p5}" valign="top">
							<xsl:value-of select="$L1Type"/>
						</td>
						<td width="{$colWidth1p5}" valign="top">
							<xsl:value-of select="@Description"/>
						</td>
						<td width="{$colWidth1p5}" valign="top">
							<xsl:value-of select="$outType"/>
						</td>
						<td width="{$colWidth1}" valign="top">
							<xsl:value-of select="@TagName"/>
						</td>
					</tr>
				</xsl:for-each>
			</tbody>
		</table>

		<xsl:if test="//z:row/tblLevel1Motors">
			<h3>Level 1 Motors</h3>
			<table>
				<tbody>
					<tr bgcolor="{$bg1}">
						<th align="left">Actuator</th>
						<th align="left">Tag Name</th>
						<th align="left">Description</th>
						<th align="left">Input</th>
						<th align="left">Output</th>
					</tr>
					<xsl:for-each select="//z:row/tblLevel1Motors">
						<tr bgcolor="{$bg2}">
							<td width="{$colWidth1}" valign="top">
								<xsl:value-of select="@ActuatorName"/>
							</td>
							<td width="{$colWidth1p5}" valign="top">
								<xsl:value-of select="@TagName"/>
							</td>
							<td width="{$colWidth1p5}" valign="top">
								<xsl:value-of select="@Description"/>
							</td>
							<td width="{$colWidth1p5}" valign="top">
								<xsl:value-of select="@Acknowledge"/>
							</td>
							<td width="{$colWidth1}" valign="top">
								<xsl:value-of select="@Output"/>
							</td>
						</tr>
					</xsl:for-each>
				</tbody>
			</table>
		</xsl:if>

		<br/>

		<h3>Level 1 Measurements</h3>
		<table>
			<tbody>
				<tr bgcolor="{$bg1}">
					<th align="left">Actuator</th>
					<th align="left">Type</th>
					<th align="left">TagName</th>
				</tr>
				<xsl:for-each select="//z:row/tblLevel1Measurements">
					<xsl:variable name="L1Type">
						<xsl:call-template name="GetL1TypeName">
							<xsl:with-param name="Level1ID" select="@Level1ID"/>
							<!-- specify tblLevel1Measurements -->
							<xsl:with-param name="tbl" select="1"/>
						</xsl:call-template>
					</xsl:variable>
					<tr bgcolor="{$bg2}">
						<td width="{$colWidth1}" valign="top">
							<xsl:value-of select="@ActuatorName"/>
						</td>
						<td width="{$colWidth1p5}" valign="top">
							<xsl:value-of select="$L1Type"/>
						</td>
						<td width="{$colWidth1}" valign="top">
							<xsl:value-of select="@TagName"/>
						</td>
					</tr>
				</xsl:for-each>
			</tbody>
		</table>
		<br/>
		<br/>
		<h2>CD Control</h2>
		<h3>Actuators</h3>
		<table>
			<tbody>
				<tr bgcolor="{$bg1}">
					<th align="left">Description</th>
					<th align="left">Type</th>
					<th align="left">#Zones</th>
					<th align="left">Switched</th>
					<th align="left">Node</th>
					<th align="left">Orientation</th>
				</tr>
				<xsl:for-each select="//z:row/tblActuators">
					<xsl:variable name="ActID" select="@ActuatorID"/>
					<xsl:variable name="ActNode">
						<xsl:call-template name="ActuatorNodeName">
							<xsl:with-param name="ActuatorID" select="$ActID"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:variable name="ActSwitched">
						<xsl:choose>
							<xsl:when test="//tblClassicCDControls/@Actuator=$ActID and //tblHMCActsbyHMC/tblHMCActuators/@HMCActuator=$ActID">
								<xsl:value-of select="'Yes'"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="'No'"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<tr bgcolor="{$bg2}">
						<td width="{$colWidth1p5}" valign="top">
							<xsl:value-of select="@Description"/>
						</td>
						<td width="{$colWidth2}" valign="top">
							<xsl:value-of select="@ActuatorTypeName"/>
						</td>
						<td width="{$colWidthp75}" valign="top">
							<xsl:value-of select="@NumberZones"/>
						</td>
						<td width="{$colWidthp75}" valign="top">
							<xsl:value-of select="$ActSwitched"/>
						</td>
						<td width="{$colWidth1}" valign="top">
							<xsl:value-of select="$ActNode"/>
						</td>
						<td width="{$colWidth1}" valign="top">
							<xsl:choose>
								<xsl:when test="$ORI_Act1atFront=@Orientation">Act1 at Front</xsl:when>
								<xsl:when test="$ORI_Act1atBack=@Orientation">Act1 at Back</xsl:when>
							</xsl:choose>
						</td>
					</tr>
				</xsl:for-each>
			</tbody>
		</table>
		<!--<h3>Classical CD Control</h3>
		<table>
			<tbody>
				<tr bgcolor="{$bg1}">
					<th align="left">Description</th>
					<th align="left">Actuator Type</th>
					<th align="left">Actuator Description</th>
					<th align="left">#Zones</th>
					<th align="left">Meas 1</th>
					<th align="left">Meas 2</th>
					<th align="left">Node</th>
				</tr>
				<xsl:for-each select="//z:row/tblClassicCDControls">
					<xsl:variable name="actType" select="//tblActuators[@ActuatorID=current()/@Actuator]/@ActuatorTypeName"/>
					<xsl:variable name="actDes" select="//tblActuators[@ActuatorID=current()/@Actuator]/@Description"/>
					<xsl:variable name="actZones" select="//tblActuators[@ActuatorID=current()/@Actuator]/@NumberZones"/>
					<xsl:variable name="cdNode" select="//tblNodes[@NodeID=current()/@Node]/@NodeName"/>
					<xsl:variable name="cdM1ID" select="./tblCDMeasurements[position()=1]/@MeasurementID"/>
					<xsl:variable name="cdMeas1" select="//tblControlledMeasurements/tblMeasurements[@MeasurementID=$cdM1ID]/@MeasName"/>
					<xsl:variable name="cdM2ID" select="./tblCDMeasurements[position()=2]/@MeasurementID"/>
					<xsl:variable name="cdMeas2" select="//tblControlledMeasurements/tblMeasurements[@MeasurementID=$cdM2ID]/@MeasName"/>
					<tr bgcolor="{$bg2}">
						<td width="{$colWidth1p5}" valign="top">
							<xsl:value-of select="@Description"/>
						</td>
						<td width="{$colWidth2}" valign="top">
							<xsl:value-of select="$actType"/>
						</td>
						<td width="{$colWidth1p5}" valign="top">
							<xsl:value-of select="$actDes"/>
						</td>
						<td width="{$colWidthp75}" valign="top">
							<xsl:value-of select="$actZones"/>
						</td>
						<td width="{$colWidthp75}" valign="top">
							<xsl:value-of select="$cdMeas1"/>
						</td>
						<td width="{$colWidthp75}" valign="top">
							<xsl:value-of select="$cdMeas2"/>
						</td>
						<td width="{$colWidth1}" valign="top">
							<xsl:value-of select="$cdNode"/>
						</td>
					</tr>
				</xsl:for-each>
			</tbody>
		</table>-->
		<xsl:for-each select="//z:row/tblHMCsByJobOrder">
			<xsl:variable name="HMCID" select="@HMCID"/>
			<h3>
				<xsl:text>Multivariable CD Control </xsl:text>
				<xsl:value-of select="@AppIndex"/>
			</h3>
			<h4>Application</h4>
			<table>
				<tbody>
					<xsl:variable name="MCDType">
						<xsl:choose>
							<xsl:when test="@HMCTypeID=$PaperMachine">PaperMachine</xsl:when>
							<xsl:when test="@HMCTypeID=$Supercalender">Supercalender</xsl:when>
							<xsl:otherwise>
								<xsl:text>Unknown</xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<xsl:variable name="NodeID" select="@HMCNode"/>
					<xsl:variable name="MCDNodeName" select="//tblNodes[@NodeID=$NodeID]/@NodeName"/>
					<tr bgcolor="{$bg1}">
						<th align="left">Name</th>
						<th align="left">Description</th>
						<th align="left">Type</th>
						<th align="left">Dimension</th>
						<th align="left">Node</th>
					</tr>
					<tr bgcolor="{$bg2}">
						<td width="{$colWidthp75}" valign="top">
							<xsl:value-of select="@AppName"/>
						</td>
						<td width="{$colWidth1p5}" valign="top">
							<xsl:value-of select="@Description"/>
						</td>
						<td width="{$colWidth1}" valign="top">
							<xsl:value-of select="$MCDType"/>
						</td>
						<td width="{$colWidthp75}" valign="top">
							<xsl:value-of select="count(//tblHMCMeasbyHMC[@HMCID=$HMCID]/tblHMCMeasurements)"/>
							<xsl:text> by </xsl:text>
							<xsl:value-of select="count(//tblHMCActsbyHMC[@HMCID=$HMCID]/tblHMCActuators)"/>
						</td>
						<td width="{$colWidth1}" valign="top">
							<xsl:value-of select="$MCDNodeName"/>
						</td>
					</tr>
				</tbody>
			</table>
			<h4>Measurements</h4>
			<table>
				<tbody>
					<tr bgcolor="{$bg1}">
						<th align="left">Number</th>
						<th align="left">Measurement Description</th>
						<th align="left">MCD Name</th>
					</tr>
					<xsl:for-each select="//tblHMCMeasbyHMC[@HMCID=$HMCID]/tblHMCMeasurements">
						<xsl:variable name="measDes" select="//z:row/tblScanners/tblMeasurements[@MeasurementID=current()/@HMCMeasurement]/@Description"/>
						<xsl:variable name="measName" select="//z:row/tblScanners/tblMeasurements[@MeasurementID=current()/@HMCMeasurement]/@MeasName"/>
						<tr bgcolor="{$bg2}">
							<td width="{$colWidthp75}" valign="top">
								<xsl:value-of select="@MeasIndex"/>
							</td>
							<td width="{$colWidth2}" valign="top">
								<xsl:value-of select="$measDes"/>
							</td>
							<td width="{$colWidthp75}" valign="top">
								<xsl:value-of select="$measName"/>
							</td>
						</tr>
					</xsl:for-each>
				</tbody>
			</table>
			<h4>Actuators</h4>
			<table>
				<tbody>
					<tr bgcolor="{$bg1}">
						<th align="left">Number</th>
						<th align="left">Actuator Description</th>
						<th align="left">MCD Name</th>
						<th align="left">MCD Description</th>
						<th align="left">#Zones</th>
					</tr>
					<xsl:for-each select="//tblHMCActsbyHMC[@HMCID=$HMCID]/tblHMCActuators">
						<xsl:variable name="actDes" select="//tblActuators[@ActuatorID=current()/@HMCActuator]/@Description"/>
						<tr bgcolor="{$bg2}">
							<td width="{$colWidthp75}" valign="top">
								<xsl:value-of select="@ActIndex"/>
							</td>
							<td width="{$colWidth2}" valign="top">
								<xsl:value-of select="$actDes"/>
							</td>
							<td width="{$colWidthp75}" valign="top">
								<xsl:value-of select="@oName"/>
							</td>
							<td width="{$colWidth2}" valign="top">
								<xsl:value-of select="@HMCActuatorDescription"/>
							</td>
							<td width="{$colWidthp75}" valign="top">
								<xsl:value-of select="@NumActs"/>
							</td>
						</tr>
					</xsl:for-each>
				</tbody>
			</table>
			<h4>Controllers</h4>
			<table>
				<tbody>
					<tr bgcolor="{$bg1}">
						<th align="left">Number</th>
						<th align="left">Name</th>
						<th align="left">Description</th>
						<th align="left">Measurements</th>
						<th align="left">Actuators</th>
					</tr>
					<xsl:for-each select="tblHMCCDControls">
						<tr bgcolor="{$bg2}">
							<td width="{$colWidthp75}" valign="top">
								<xsl:value-of select="@ControlIndex"/>
							</td>
							<td width="{$colWidthp75}" valign="top">
								<xsl:value-of select="@HMCControlName"/>
							</td>
							<td width="{$colWidth1p5}" valign="top">
								<xsl:value-of select="@HMCControlDescription"/>
							</td>
							<td width="{$colWidth2}" valign="top">
								<xsl:for-each select="tblHMCControlMeas">
									<xsl:variable name="HMCMeasurementID" select="@HMCMeasurementID"/>
									<xsl:variable name="MeasurementID" select="//tblHMCMeasbyHMC[@HMCID=$HMCID]/tblHMCMeasurements[@HMCMeasurementID=$HMCMeasurementID]/@HMCMeasurement"/>
									<xsl:value-of select="//z:row/tblScanners/tblMeasurements[@MeasurementID=$MeasurementID]/@MeasName"/>
									<xsl:if test="not(position()=last())">
										<xsl:text>, </xsl:text>
									</xsl:if>
								</xsl:for-each>
							</td>
							<td width="{$colWidth2}" valign="top">
								<xsl:for-each select="tblHMCControlActs">
									<xsl:variable name="HMCActuatorID" select="@HMCActuatorID"/>
									<xsl:value-of select="//tblHMCActsbyHMC[@HMCID=$HMCID]/tblHMCActuators[@HMCActuatorID=$HMCActuatorID]/@oName"/>
									<xsl:if test="not(position()=last())">
										<xsl:text>, </xsl:text>
									</xsl:if>
								</xsl:for-each>
							</td>
						</tr>
					</xsl:for-each>
				</tbody>
			</table>
			<xsl:if test="position() = last()">
				<h3>Multivariable CD Interlocks</h3>
				<table>
					<tbody>
						<tr bgcolor="{$bg1}">
							<th align="left">Number</th>
							<th align="left">Name</th>
						</tr>
						<xsl:for-each select="//z:row/tblHMCsByJobOrder">
							<xsl:if test="position() = 1">
								<xsl:for-each select="tblHMCInterlocks">
									<tr bgcolor="{$bg2}">
										<td width="{$colWidthp75}" valign="top">
											<xsl:value-of select="@Index"/>
										</td>
										<td width="{$colWidth2}" valign="top">
											<xsl:value-of select="@HMCInterlockName"/>
										</td>
									</tr>
								</xsl:for-each>
							</xsl:if>
						</xsl:for-each>
					</tbody>
				</table>
			</xsl:if>
		</xsl:for-each>
		<br/>
		<xsl:for-each select="//z:row/tblHMMDsByJobOrder">
			<xsl:variable name="HMMDID" select="@HMMDID"/>
			<h3>
				<xsl:text>PPC Control </xsl:text>
				<xsl:value-of select="@AppIndex"/>
			</h3>
			<h4>Application</h4>
			<table>
				<tbody>
					<xsl:variable name="MMDType">
						<!-- To be updated after updating MDControl.xslt to include HMMD Types -->
						<xsl:choose>
							<xsl:when test="@HMMDTypeID='1'">MMD</xsl:when>
							<xsl:when test="@HMMDTypeID='2'">IMC</xsl:when>
							<xsl:when test="@HMMDTypeID='3'">PMC</xsl:when>
							<xsl:otherwise>
								<xsl:text>Unknown</xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<xsl:variable name="NodeID" select="@HMMDNode"/>
					<xsl:variable name="MMDNodeName" select="//tblNodes[@NodeID=$NodeID]/@NodeName"/>
					<tr bgcolor="{$bg1}">
						<th align="left">Name</th>
						<th align="left">Type</th>
						<th align="left">Dimension</th>
						<th align="left">Node</th>
					</tr>
					<tr bgcolor="{$bg2}">
						<td width="{$colWidthp75}" valign="top">
							<xsl:value-of select="@Description"/>
						</td>
						<td width="{$colWidth1}" valign="top">
							<xsl:value-of select="$MMDType"/>
						</td>
						<td width="{$colWidthp75}" valign="top">
							<xsl:value-of select="count(//tblHMMDContVariables[@HMMDID=$HMMDID])"/>
							<xsl:text> by </xsl:text>
							<xsl:value-of select="count(//tblHMMDManVariables[@HMMDID=$HMMDID])"/>
						</td>
						<td width="{$colWidth1}" valign="top">
							<xsl:value-of select="$MMDNodeName"/>
						</td>
					</tr>
				</tbody>
			</table>
			<h4>Controlled Variables</h4>
			<table>
				<tbody>
					<tr bgcolor="{$bg1}">
						<th align="left">ShortName</th>
						<th align="left">Description</th>
						<th align="left">Control Name</th>
					</tr>
					<xsl:for-each select="//tblHMMDContVariables[@HMMDID=$HMMDID]">
						<xsl:variable name="ID" select="@ControlledVariable"/>
						<xsl:variable name="measDes" select="//z:row/tblScanners/tblMeasurements[@MeasurementID=current()/@ControlledVariable]/@Description"/>
						<xsl:variable name="measName" select="//z:row/tblScanners/tblMeasurements[@MeasurementID=current()/@ControlledVariable]/@MeasName"/>
						<xsl:variable name="measDesEX" select="//z:row/tblExtMDMeasurements[@ExtMDMeasID=$ID]/@ExtMDMeasName"/>
						<xsl:variable name="measNameEX" select="//z:row/tblExtMDMeasurements[@ExtMDMeasID=$ID]/@ExtMDMeasName"/>
						<tr bgcolor="{$bg2}">
							<td width="{$colWidthp75}" valign="top">
								<xsl:value-of select="@Shortname"/>
							</td>
							<td width="{$colWidth2}" valign="top">
								<xsl:value-of select="$measDes"/>
								<xsl:value-of select="$measDesEX"/>
							</td>
							<td width="{$colWidthp75}" valign="top">
								<xsl:value-of select="$measName"/>
								<xsl:value-of select="$measNameEX"/>
							</td>
						</tr>
					</xsl:for-each>
				</tbody>
			</table>
			<h4>Manipulated Variables</h4>
			<table>
				<tbody>
					<tr bgcolor="{$bg1}">
						<th align="left">Name</th>
						<th align="left">ShortName</th>
						<th align="left">Description</th>
					</tr>
					<xsl:for-each select="//tblHMMDManVariables[@HMMDID=$HMMDID]">
						<xsl:variable name="L1MeasDes" select="//tblLevel1Measurements[@Level1ID=current()/@ShortName]/@Description"/>
						<xsl:variable name="L1ContDes" select="//tblLevel1Controls[@Level1ID=current()/@ShortName]/@Description"/>
						<xsl:variable name="L1MeasName" select="//tblLevel1Measurements[@Level1ID=current()/@ShortName]/@ActuatorName"/>
						<xsl:variable name="L1ContName" select="//tblLevel1Controls[@Level1ID=current()/@ShortName]/@ActuatorName"/>
						<xsl:variable name="Count">
							<xsl:number count=" tblHMMDManVariables[@HMMDID=$HMMDID] " level="any"/>
						</xsl:variable>
						<xsl:variable name="MVName">MV<xsl:value-of select="format-number($Count,'00')"/>
						</xsl:variable>
						<tr bgcolor="{$bg2}">
							<td width="{$colWidthp75}" valign="top">
								<xsl:value-of select="$MVName"/>
							</td>
							<td width="{$colWidth2}" valign="top">
								<xsl:value-of select="$L1MeasName"/>
								<xsl:value-of select="$L1ContName"/>
							</td>
							<td width="{$colWidthp75}" valign="top">
								<xsl:value-of select="$L1MeasDes"/>
								<xsl:value-of select="$L1ContDes"/>
							</td>
						</tr>
					</xsl:for-each>
				</tbody>
			</table>
		</xsl:for-each>
		<br/>
		<br/>
		<xsl:if test="$ColorControlExists='true'">
			<h2>Color Controls</h2>
			<h3>General Color Setup</h3>
			<table>
				<tbody>
					<xsl:for-each select="//z:row/tblColorControlGeneral ">
						<tr bgcolor="{$bg1}">
							<th align="left">Group Start</th>
							<th align="left">Dye Calibration Measurement</th>
							<th align="left">Auto Shade Change</th>
						</tr>
						<tr bgcolor="{$bg2}">
							<td width="{$colWidth1}" valign="top">
								<xsl:value-of select="@GroupStart"/>
							</td>
							<td width="{$colWidth3}" valign="top">
								<xsl:value-of select="//tblMeasurements[@MeasurementID=current()/@DyeCalibrationID]/@Description"/>
							</td>
							<td width="{$colWidth3}" valign="top">
								<xsl:value-of select="@AutoShadeChange"/>
							</td>
						</tr>
					</xsl:for-each>
				</tbody>
			</table>
			<h3>Controls</h3>
			<table>
				<tbody>
					<tr bgcolor="{$bg1}">
						<th align="left">Name</th>
						<th align="left">Description</th>
						<th align="left">Measurement</th>
						<th align="left">OBA Control</th>
						<th align="left">OBA Description</th>
					</tr>
					<xsl:for-each select="//z:row/tblColorControls">
						<tr bgcolor="{$bg2}">
							<td width="{$colWidth1}" valign="top">
								<xsl:value-of select="@CtrlName"/>
							</td>
							<td width="{$colWidth1p5}" valign="top">
								<xsl:value-of select="@ColorDescription"/>
							</td>
							<td width="{$colWidth1p5}" valign="top">
								<xsl:value-of select="//tblMeasurements[@MeasurementID=current()/@MeasID]/@Description"/>
							</td>
							<td width="{$colWidth1}" valign="top">
								<xsl:value-of select="@OBAEnable"/>
							</td>
							<td width="{$colWidth2}" valign="top">
								<xsl:value-of select="@OBADescription"/>
							</td>
						</tr>
					</xsl:for-each>
				</tbody>
			</table>
			<h3>Dry End Thruput</h3>
			<table>
				<tbody>
					<tr bgcolor="{$bg1}">
						<th align="left">Speed</th>
						<th align="left">Conditioned Weight</th>
					</tr>
					<xsl:for-each select="//z:row/tblColorControlThruput">
						<tr bgcolor="{$bg2}">
							<td width="{$colWidth1}" valign="top">
								<xsl:value-of select="@Speed"/>
							</td>
							<td width="{$colWidth3}" valign="top">
								<xsl:value-of select="//tblMeasurements[@MeasurementID=current()/@CondWeight]/@Description"/>
							</td>
						</tr>
					</xsl:for-each>
				</tbody>
			</table>
			<h3>Wet End Thruput 1</h3>
			<table>
				<tbody>
					<tr bgcolor="{$bg1}">
						<th align="left">Stock Flow</th>
						<th align="left">Consistency</th>
					</tr>
					<xsl:for-each select="//z:row/tblColorControlThruput">
						<tr bgcolor="{$bg2}">
							<td width="{$colWidth1}" valign="top">
								<xsl:value-of select="@StockFlow1"/>
							</td>
							<td width="{$colWidth1}" valign="top">
								<xsl:value-of select="@Consistency1"/>
							</td>
						</tr>
					</xsl:for-each>
				</tbody>
			</table>
			<h3>Wet End Thruput 2</h3>
			<table>
				<tbody>
					<tr bgcolor="{$bg1}">
						<th align="left">Stock Flow</th>
						<th align="left">Consistency</th>
					</tr>
					<xsl:for-each select="//z:row/tblColorControlThruput">
						<tr bgcolor="{$bg2}">
							<td width="{$colWidth1}" valign="top">
								<xsl:value-of select="@StockFlow2"/>
							</td>
							<td width="{$colWidth1}" valign="top">
								<xsl:value-of select="@Consistency2"/>
							</td>
						</tr>
					</xsl:for-each>
				</tbody>
			</table>
		</xsl:if>
		<br/>
		<br/>
		<h2>MIS Features</h2>
		<h3>Roll-Set</h3>
		<table>
			<tbody>
				<tr bgcolor="{$bg1}">
					<th align="left">Measurement 1</th>
					<th align="left">Measurement 2</th>
				</tr>
				<xsl:for-each select="//z:row/tblRollSet">
					<xsl:variable name="rsMeas1" select="//tblMeasurements[@MeasurementID=current()/@Measurement1]/@Description"/>
					<xsl:variable name="rsMeas2" select="//tblMeasurements[@MeasurementID=current()/@Measurement2]/@Description"/>
					<tr bgcolor="{$bg2}">
						<td width="{$colWidth2}" valign="top">
							<xsl:value-of select="$rsMeas1"/>
						</td>
						<td width="{$colWidth2}" valign="top">
							<xsl:value-of select="$rsMeas2"/>
						</td>
					</tr>
				</xsl:for-each>
			</tbody>
		</table>

		<br/>
		<br/>
		<h2>External Profiles</h2>
		<table>
			<tbody>
				<tr bgcolor="{$bg1}">
					<th align="left">Name</th>
					<th align="left">Node</th>
					<th align="left">Use Fisrt/Last DB</th>
					<th align="left">Zero Based Index</th>
					<th align="left">Composite Timeout Enabled</th>
					<th align="left">Invalid Value Enabled</th>
					<th align="left">Invalid Value</th>
					<th align="left">Maximum Invalid Boxes</th>
					<th align="left">Ignore invalid Values</th>
				</tr>
				<xsl:for-each select="//tblExtProfiles">
					<xsl:variable name="extProfID" select="@ExtProfileID"/>
					<tr bgcolor="{$bg2}">
						<td width="{$colWidth1}" valign="top">
							<xsl:value-of select="@ExtProfileName"/>
						</td>
						<td width="{$colWidth1}" valign="top">
							<xsl:variable name="node" select="/*/*/*/tblExtProfiles[@ExtProfileID = $extProfID]/tblExtProfConfig[@Description='OPCServerNode']/@ConfigValue"/>
							<xsl:value-of select="$node"/>
						</td>
						<td width="{$colWidth1}" valign="top">
							<xsl:value-of select="@UseFirstLastBox"/>
						</td>
						<td width="{$colWidth1}" valign="top">
							<xsl:value-of select="@ZeroBasedIndex"/>
						</td>
						<td width="{$colWidth1}" valign="top">
							<xsl:value-of select="@CompositeTimeoutEnabled"/>
						</td>
						<td width="{$colWidth1}" valign="top">
							<xsl:value-of select="@InvalidValueEnabled"/>
						</td>
						<td width="{$colWidth1}" valign="top">
							<xsl:value-of select="@InvalidValue"/>
						</td>
						<td width="{$colWidth1}" valign="top">
							<xsl:value-of select="@MaxInvalidBoxes"/>
						</td>
						<td width="{$colWidth1}" valign="top">
							<xsl:value-of select="@ReplaceInvalidWithMean"/>
						</td>
					</tr>
				</xsl:for-each>
			</tbody>
		</table>
		<br/>
		<br/>
		<!-- -->
		<h2>External MD Measurements</h2>
		<table>
			<tbody>
				<tr bgcolor="{$bg1}">
					<th align="left">Name</th>
					<th align="left">Node</th>
					<th align="left">Server</th>
					<th align="left">Linked Scanner</th>
					<th align="left">Configuration Type</th>
				</tr>
				<xsl:for-each select="//tblExtMDMeasurements">
					<xsl:variable name="extMDMeasID" select="@ExtMDMeasID"/>
					<xsl:variable name="configType" select="@ExtMDMeasConfigType"/>
					<xsl:variable name="configTypeName">
						<xsl:choose>
							<xsl:when test="$configType=1">Manual (AC800 MD)</xsl:when>
							<xsl:when test="$configType=2">OPC (AC800 MD)</xsl:when>
							<xsl:when test="$configType=3">ACA Porosity</xsl:when>
							<xsl:when test="$configType=4">ABB OSS Engine</xsl:when>
							<xsl:otherwise/>
						</xsl:choose>
					</xsl:variable>
					<tr bgcolor="{$bg2}">
						<td width="{$colWidth1}" valign="top">
							<xsl:value-of select="@ExtMDMeasName"/>
						</td>
						<td width="{$colWidth1}" valign="top">
							<xsl:variable name="node" select="/*/*/*/tblExtMDMeasurements[@ExtMDMeasID = $extMDMeasID]/tblExtMDMeasConfig[@Description='OPCServerNode']/@ConfigValue"/>
							<xsl:value-of select="$node"/>
						</td>
						<td width="{$colWidth1}" valign="top">
							<xsl:variable name="serverName" select="/*/*/*/tblExtMDMeasurements[@ExtMDMeasID = $extMDMeasID]/tblExtMDMeasConfig[@Description='OPCServerName']/@ConfigValue"/>
							<xsl:value-of select="$serverName"/>
						</td>
						<td width="{$colWidth1}" valign="top">
							<xsl:value-of select="@ExtMDMeasScanner"/>
						</td>
						<td width="{$colWidth1p5}" valign="top">
							<xsl:value-of select="$configTypeName"/>
						</td>
					</tr>
				</xsl:for-each>
			</tbody>
		</table>
		<br/>
		<br/>
		<!-- -->
		<h2>Advanced Features</h2>
		<h3>General</h3>
		<table>
			<tbody>
				<tr bgcolor="{$bg1}">
					<td width="{$colWidth2}">
						<b>Synchronized Scanning</b>
					</td>
					<td>
						<xsl:value-of select="@SynchronizedScanning"/>
					</td>
				</tr>
				<tr bgcolor="{$bg2}">
					<td width="{$colWidth2}">
						<b>Tracking Machine Speed Tag</b>
					</td>
					<td>
						<xsl:value-of select="@TrackingMachineSpeedTag"/>
					</td>
				</tr>
				<tr bgcolor="{$bg1}">
					<td width="{$colWidth2}">
						<b>Tracking Machine Speed Minimum</b>
					</td>
					<td>
						<xsl:value-of select="@TrackingMachineSpeedMinimum"/>
					</td>
				</tr>
				<tr bgcolor="{$bg2}">
					<td width="{$colWidth2}">
						<b>Standardize Duration</b>
					</td>
					<td>
						<xsl:value-of select="@StandardizeDuration"/>
					</td>
				</tr>
				<tr bgcolor="{$bg1}">
					<td width="{$colWidth2}">
						<b>Global Stdz Interval Mins</b>
					</td>
					<td>
						<xsl:value-of select="@GlobalStdzIntervalMins"/>
					</td>
				</tr>
				<tr bgcolor="{$bg1}">
					<td width="{$colWidth2}">
						<b>Filter Timeout Secs</b>
					</td>
					<td>
						<xsl:value-of select="@FilterTimeoutSecs"/>
					</td>
				</tr>
				<tr bgcolor="{$bg1}">
					<td width="{$colWidth2}">
						<b>ResetFilter On Grade</b>
					</td>
					<td>
						<xsl:value-of select="@ResetFilterOnGrade"/>
					</td>
				</tr>
				<tr bgcolor="{$bg1}">
					<td width="{$colWidth2}">
						<b>Reset Filter When Invalid</b>
					</td>
					<td>
						<xsl:value-of select="@ResetFilterWhenInvalid"/>
					</td>
				</tr>
			</tbody>
		</table>
	</xsl:template>
	<xsl:template match="/">
		<html>
			<head>
				<title>Industrial IT Quality Control - Job Order Configuration</title>
				<style type="text/css">
					h1 {font-family: arial; font-size: 150%}
					h2 {page-break-before: always; font-family: arial; font-size: 130%}
					h5 {page-break-before: never; font-family: arial; font-size: 130%}
					h3 {font-family: arial; font-size: 100%}
					p { font: 900 12px verdana}
					
					table
					{text-align: left;
					font-family: Arial, Helvetica, sans-serif ;
					font-weight: normal;
					font-size: 12px;
					border: 0px;
					border-collapse: collapse;
					border-spacing: 0px;}

					table td
					{background-color: #D3D3D3;
					color: #000;
					padding: 4px;
					text-align: left;
					border-bottom: 2px #fff solid;
					font-size: 12px;
					font-weight: normal;} 

					</style>
			</head>
			<body>
				<xsl:apply-templates select="*"/>
			</body>
		</html>
	</xsl:template>
</xsl:stylesheet>
