<?xml version="1.0" encoding="UTF-8"?>
<!-- Globals.xslt
Description:
This file contains global variable declarations and utility templates.
Worksheets
Notes:
This file is compatible with the msxml / msxsl 4.0 XML parser and transform tools.

History:
2001-12-18 		Original		R. Trent Garverick
2002-08-27		Moved script from main.xslt to here 				RTG
2002-09-18		Added IOWorkSheet Path logic					RTG
2002-09-26		Changed IOWorksheet to IOWorksheets			RTG
2002-10-08		Removed MachineNumber variable				RTG
2002-10-10		Added GetDBPath function						RTG
2002-10-10		Added variables (moved from DirectStruct.xslt)	RTG
2002-11-21		Added variable MITConfigFolder for labels.xml	RTG
2002-11-22		Added variable ShadeHelp						WLH
2002-12-12		Added ABBScannersExist flag					RTG		
2002-12-16		Added variable HealthText						WLH
2003-01-17		Added SetFileReadOnly Function					RTG
2003-01-23		Added ClearReadOnly Function					RTG
2002-11-22		Added variable GradeHelp						WLH
2003-11-14		Added ActIOWorksheets						RBE
2003-11-20		Added  ABB LVC Exist variable					MPK
2004-08-06		Add Color Control Variabkles						MPK
2004-10-08		Add more Color Control Variabkles						TFM
2004-11-23		Added CheckFileExists Function for MD_MergeFiles.xslt	DMC
2004-11-24		Added GetCurrentTime function							MPK
2005-08-15		Added PlatformBaseline41 variable						MPK
2005-11-29		Added PlatformBaseline50 variable						MPK
2006-11-08		Modified PlatformBaseline50 variable to be PlatformBaseline41R3c						PJL
2007-01-23		Added processing for PlatformBaseline41R5d				PJL
2007-08-09		Added AC800Connect50SP1 varaible and removed PlatformBaseline.... variables		PJL
2008-06-04		Integrated MCD: added variables for MCD, CD Switch and orientation	AZ
2008-06-06		Fixed ScannerNumber template		AZ
2008-06-16		Removed Soft Measurements		AZ
2009-07-29		Added new Ind_SupplyPanelExists global variable used for building new style panel		PJL
2011-05-19		Set Ind_SupplyPanelExists global variable to true so that variables expected by lib are included		PJL
2016-08-30		Added MCD exists flag								PJL

-->
<xsl:stylesheet 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:rs="urn:schemas-microsoft-com:rowset" 
	xmlns:z="#RowsetSchema"
	xmlns:msxsl="urn:schemas-microsoft-com:xslt"
	xmlns:abb="http://www.abb.com/AutomationTechnologyProducts">
	
	<xsl:import href="NodeTypes.xslt"/>
	<xsl:import href="OrientationTypes.xslt"/>
	<xsl:import href="Measurements.xslt"/>
	
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	<!-- 
	******************************************************
	Global Variables
	******************************************************		
	-->
	<!--JobOrder -->
	<xsl:variable name="JobOrder" select="//*/@JobOrder"/>
	<xsl:variable name="NullString" select="''"/>

	<!-- Machine Name -->
	<xsl:variable name="MachineName" select="//*/@MachineName"/>
	<!-- QCS Root OPC Branch -->
	<xsl:variable name="QCSRoot">
		<xsl:value-of select="$MachineName"/>
		<xsl:text>.SQCS</xsl:text>
	</xsl:variable>
	<!-- main qc application node UNC path (\\nodename) -->
	<xsl:variable name="MainNodeName">
		<xsl:choose>
		<xsl:when test="count(/*/*/*/tblNodes[@NodeType=$StdMCDNode]) > 0">
		<xsl:value-of select="/*/*/*/tblNodes[@NodeType=$StdMCDNode]/@NodeName"/>
		</xsl:when>
		<xsl:otherwise>
		<xsl:value-of select="//tblNodes[@NodeType=$MainNode]/@NodeName"/>
		</xsl:otherwise>
	</xsl:choose>
	</xsl:variable>
	<xsl:variable name="MainQCNodeUNC">
		<xsl:value-of select="concat('\\', $MainNodeName, '\')"/>
	</xsl:variable>
	<!-- secondary qc application node UNC path (\\nodename) -->
	<xsl:variable name="SecondaryNodeName">
		<xsl:value-of select="//tblNodes[@NodeType=$CDNode]/@NodeName"/>
	</xsl:variable>
	<xsl:variable name="HMCControlNodeName">
		<xsl:value-of select="//tblNodes[@NodeType=$MCDNode]/@NodeName"/>
	</xsl:variable>
	<!-- Flag for CD Switch -->
	<xsl:variable name="CDSwitchExists">
		<xsl:choose>
			<xsl:when test="count(//tblClassicCDControls)>0 and count(//tblHMCsByJobOrder)>0">
				<xsl:value-of select="1"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="0"/>
			</xsl:otherwise>
		</xsl:choose>	
	</xsl:variable>
	<!-- MCD Exist Flag -->
	<xsl:variable name="MCDControlExists">
		<xsl:value-of select="count(//tblHMCsByJobOrder)"/>
	</xsl:variable>
	<!-- AC800M Controller Connectivity Server PC Node ID -->
	<xsl:variable name="AC800MNodeID" select="//z:row/@AC800M"/>
	<!-- AC800M Controller Connectivity Server PC node name -->
	<xsl:variable name="AC800MNode">
	<xsl:choose>
		<xsl:when test="count(/*/*/*/tblNodes[@NodeType=$StdMCDNode]) > 0">
		<xsl:value-of select="//tblNodes[@NodeType = $StdMCDNode]/@NodeName"/>
		</xsl:when>
		<xsl:otherwise>
		<xsl:value-of select="//tblNodes[@NodeID=$AC800MNodeID]/@NodeName"/>
		</xsl:otherwise>
	</xsl:choose>
	</xsl:variable>
  <!-- We use Main node instead of PPA for now-->
	<!-- Process Portal Server PC Node ID -->
	<xsl:variable name="PPASvrNodeID">
	<xsl:choose>
		<xsl:when test="count(/*/*/*/tblNodes[@NodeType=$StdMCDNode]) > 0">
		<xsl:value-of select="//tblNodes[@NodeType = $StdMCDNode]/@NodeID"/>
		</xsl:when>
		<xsl:otherwise>
		<xsl:value-of select="//tblNodes[@NodeType = $MainNode]/@NodeID"/>
		</xsl:otherwise>
	</xsl:choose>
	</xsl:variable>
	<!-- Process Portal Server PC Node name -->
	<xsl:variable name="PPAServerNode">
	<xsl:choose>
		<xsl:when test="count(/*/*/*/tblNodes[@NodeType=$StdMCDNode]) > 0">
		<xsl:value-of select="//tblNodes[@NodeType = $StdMCDNode]/@NodeName"/>
		</xsl:when>
		<xsl:otherwise>
		<xsl:choose>
		<xsl:when test="(/*/*/*/tblNodes[@NodeType=$OtherTypeNode])">
			<xsl:value-of select="//tblNodes[@NodeType = $OtherTypeNode]/@NodeName"/>
		</xsl:when>
		<xsl:otherwise>
		<xsl:value-of select="//tblNodes[@NodeType = $MainNode]/@NodeName"/>
		</xsl:otherwise>
		</xsl:choose>
		</xsl:otherwise>
	</xsl:choose>
	</xsl:variable>
  	<!-- Color Control PC Node ID -->
	<xsl:variable name="ColorControlNodeID" select="//z:row/@ColorControlNode"/>
	<!-- Color Control Node name -->
	<xsl:variable name="ColorControlNode" select="//tblNodes[@NodeID=$ColorControlNodeID]/@NodeName"/>
	<xsl:variable name="ColorControlNodeUNC">
		<xsl:value-of select="concat('\\', $ColorControlNode, '\')"/>
	</xsl:variable>
	<!-- Color Control Simulation PC Node ID -->
	<xsl:variable name="ColorControlSimNodeID" select="//z:row/@ColorControlSimNode"/>
	<!-- Color Control Node name -->
	<xsl:variable name="ColorControlSimNode" select="//tblNodes[@NodeID=$ColorControlSimNodeID]/@NodeName"/>
	<!-- Frame Simulatorl PC Node ID -->
	<xsl:variable name="FrameSimNodeID" select="//z:row/@FrameSimNode"/>
	<!-- Frame Simulator Node name -->
	<xsl:variable name="FrameSimNode" select="//tblNodes[@NodeID=$FrameSimNodeID]/@NodeName"/>
	<!-- HMC Control PC Node ID -->
	<xsl:variable name="HMCControlNodeUNC">
		<xsl:value-of select="concat('\\', $HMCControlNodeName, '\')"/>
	</xsl:variable>
	<!-- MCD Simulatorl PC Node ID -->
	<xsl:variable name="MCDSimNodeID" select="//z:row/@MCDSimNode"/>
	<!-- MCD Simulator Node name -->
	<xsl:variable name="MCDSimNodeName" select="//tblNodes[@NodeID=$MCDSimNodeID]/@NodeName"/>

	<!-- Application root share name (combine with \\nodename\ to form UNC path) -->
	<xsl:variable name="AppShare">Paper Quality Control\</xsl:variable>
	<!-- Application root share name for new QCS Griffin (combine with \\nodename\ to form UNC path) -->
	<xsl:variable name="AppShareGriffin">Web Quality Control\</xsl:variable>
	
	<!-- Grade Code Folder path -->
	<xsl:variable name="GradeFolder">
		<xsl:value-of select="concat($AppShare, 'Grade', '\')"/>
	</xsl:variable>
	<!-- Shade Code Folder path -->
	<xsl:variable name="ShadeFolder">
		<xsl:value-of select="concat($AppShare, 'Shade', '\')"/>
	</xsl:variable>
	<!-- Config Folder path -->
	<xsl:variable name="ConfigFolder">
		<xsl:value-of select="concat($AppShare, 'System\Config', '\')"/>
	</xsl:variable>
	<!-- Persistence Folder path -->
	<xsl:variable name="PersistenceFolder">
		<xsl:value-of select="concat($AppShare, 'Persistence', '\')"/>
	</xsl:variable>
	<!-- MIT Config Folder path -->
	<xsl:variable name="MITConfigFolder">
		<xsl:value-of select="concat($AppShare, 'Measure IT\Quality Control\Config', '\')"/>
	</xsl:variable>
	<!-- Coldstart Folder path -->
	<xsl:variable name="ColdstartFolder">
		<xsl:value-of select="concat($AppShare, 'System\Config', '\')"/>
	</xsl:variable>
	<!-- color control Folder path -->
	<xsl:variable name="ColorControlFolder">
		<xsl:value-of select="concat($AppShare, 'Control IT\Color Control', '\')"/>
	</xsl:variable>
	<!-- dyes Folder path -->
	<xsl:variable name="DyeFolder">
		<xsl:value-of select="concat($AppShare, 'Control IT\Color Control\Dyes', '\')"/>
	</xsl:variable>
	
	<!-- Note: Implement script to get config hostnam -->
	<!-- ConfigHostName -->
	<xsl:variable name="ConfigHostName">
		<xsl:value-of select="abb:GetComputerName()"/>
	</xsl:variable>

	<!-- Specific Files Paths -->
	<!-- Grade Data Directory XML Path -->
	<xsl:variable name="GradeDirectory"><xsl:value-of select="concat($MainQCNodeUNC, $GradeFolder, 'gcdirectory.xml')"/></xsl:variable>
	<!-- Grade Data HelpFile Path -->
	<xsl:variable name="GradeHelp"><xsl:value-of select="concat($MainQCNodeUNC, $GradeFolder, 'gradehelp.xml')"/></xsl:variable>
	<!-- Shade Data Directory XML Path -->
	<xsl:variable name="ShadeDirectory"><xsl:value-of select="concat($MainQCNodeUNC, $ShadeFolder, 'shadedirectory.xml')"/></xsl:variable>
	<!-- Shade Data HelpFile Path -->
	<xsl:variable name="ShadeHelp"><xsl:value-of select="concat($MainQCNodeUNC, $ShadeFolder, 'shadehelp.xml')"/></xsl:variable>
	<!-- Dye Data Directory XML Path -->
	<xsl:variable name="DyeDirectory"><xsl:value-of select="concat($ColorControlNodeUNC, $DyeFolder, 'dyedirectory.xml')"/></xsl:variable>
	<!-- Dye Data HelpFile Path -->
	<xsl:variable name="DyeHelp"><xsl:value-of select="concat($ColorControlNodeUNC, $DyeFolder, 'dyehelp.xml')"/></xsl:variable>
	<!-- Coldstart file path -->
	<xsl:variable name="ColdstartPath"><xsl:value-of select="concat($ColdstartFolder, 'coldstart.xml')"/></xsl:variable>
	<!-- Label file path -->
	<xsl:variable name="LabelPath"><xsl:value-of select="concat($MITConfigFolder, 'labels.xml')"/></xsl:variable>
	<!-- HSI Tag file path -->
	<xsl:variable name="HSITagPath"><xsl:value-of select="concat($ConfigFolder, 'HSITags.xml')"/></xsl:variable>
	<!-- HSI Tag server file path -->
	<xsl:variable name="HSIServerPath"><xsl:value-of select="concat($ConfigFolder, 'HSIServer.xml')"/></xsl:variable>
	<!-- Server file path -->
	<xsl:variable name="ServerPath"><xsl:value-of select="concat($ConfigFolder, 'HSIServer.xml')"/></xsl:variable>
	<!-- HealthWatch TextFile Path -->
	<xsl:variable name="HealthText"><xsl:value-of select="concat($ConfigFolder, 'HealthWatch.xml')"/></xsl:variable>
	<!--Standard Algorthhms file path -->
	<xsl:variable name="StdAlgPath"><xsl:value-of select="concat($MITConfigFolder, 'std_algorithms.xml')"/></xsl:variable>
	<!--Calculated Measurements file path -->
	<xsl:variable name="CalcMeasPath"><xsl:value-of select="concat($ConfigFolder, 'calcmeas.xml')"/></xsl:variable>


	<!-- Color existence flag -->
	<xsl:variable name="ColorExists">
		<xsl:choose>
			<xsl:when test="//tblMeasurements[(@MeasurementTypeID=$Color) or @MeasurementTypeID=$HPColor]">true</xsl:when>
			<xsl:otherwise>false</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>

	<!-- Color Control existence flag -->
	<xsl:variable name="ColorControlExists">
		<xsl:choose>
			<xsl:when test="//tblColorControls">true</xsl:when>
			<xsl:otherwise>false</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>

	<!-- Dual Sided Color Control existence flag -->
	<xsl:variable name="ColorControlDualSided">
		<xsl:choose>
			<xsl:when test="count(/xml/rs:data/z:row/tblColorControls) > 1">
				<xsl:value-of select="'True'"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="'False'"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>

    <!-- Color Control OPC Branch name -->
    <xsl:variable name="ColorControlBranchName">
        <xsl:value-of select="'Multivariable Color Control'"/>
    </xsl:variable>


    <!-- ABB Scanners Exist flag -->
	<xsl:variable name="ABBScannersExist">
		<xsl:choose>
			<xsl:when  test="//tblScanners[@ScannerTypeID=$SP1200 or @ScannerTypeID=$SP700 or @ScannerTypeID=$SPReflection or @ScannerTypeID=$NA1200 or @ScannerTypeID=$NA700 or @ScannerTypeID=$NAReflection or @ScannerTypeID=$NP800]">
				<xsl:value-of select="'true'"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="'false'"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>

	<!-- ABB LVC Exist flag -->
	<xsl:variable name="ABBLVCExist">
		<xsl:choose>
			<xsl:when  test="//tblClassicCDControls[@LVCExists='True']">
				<xsl:value-of select="'true'"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="'false'"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>

	<!-- ABB CD CTW Control Exist flag -->
	<xsl:variable name="ABBCDCTWCExist">
		<xsl:choose>
			<xsl:when  test="//tblClassicCDControls[@CDType='2']">
				<xsl:value-of select="'true'"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="'false'"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	
	<!-- HMC Application Types -->
	<xsl:variable name="PaperMachine" select="1"/>
	<xsl:variable name="Supercalender" select="2"/>
	
	<!-- Induction xP Panel exist flag default value is False -->
	<!-- Can be set to True for old style Induction xP Panel  -->
	<xsl:variable name="Ind_SupplyPanelExists" select="'True'"/>
	
	<!-- *********************************************************************************************************************
		System 800xA Target Platform
		
		*********************************************************************************************************************
	-->
		<xsl:variable name="AC800Connect50SP1" select="1"/>
	<!--
	 ******************************************************
	Script - MS Extension
	******************************************************		
	-->

	<msxsl:script language="VBScript" implements-prefix="abb">
	<![CDATA[ 
        Option Explicit	
	
	Dim FCBNumber						'Function Block Number	
	Dim cfgFilePath						'joconfig.xml path
	Dim cfgFolder						'job order folder
	Dim xslDirPath						'XLST transform file directory path
	Dim dbPath							'database folder path
	Dim schemaPath						'Schema folder path
	Dim worksheetPath					'IO Worksheet path
	Dim ActworksheetPath					'Act IO Worksheet path
	Dim wshShell						'Windows Scripting Host Shell object
	Dim projectsDirPath					'JO Projects folder directory path
	Dim jo								'Job Order
	Dim sParam							'xslt parameter string for calling XSLT transforms
	Dim rootpath                        'root working folder ..\JOCONFIG

	'---------------------------------------------------------------------------------------------------
	'	Generate sequential FCB numbers
	'---------------------------------------------------------------------------------------------------
	Function NextFCBNumber
		On Error Resume Next
		FCBNumber = FCBNumber + 1
		NextFCBNumber = FCBNumber	
	End Function
	
  '---------------------------------------------------------------------------------------------------
	'	Reset sequential FCB numbers to 0
	'---------------------------------------------------------------------------------------------------
	Function ResetFCBNumber
		On Error Resume Next
		FCBNumber = 0
		ResetFCBNumber = FCBNumber	
	End Function
		
	'---------------------------------------------------------------------------------------------------
	'	Get Computer Name
	'---------------------------------------------------------------------------------------------------	
	
	Public Function GetComputerName()
	
 		Dim objNet
		On Error Resume Next 'In case we fail to create object then display our custom error
		
		Set objNet = CreateObject("WScript.NetWork") 
		
		If  Err.Number = 0 Then
			GetComputerName = objNet.ComputerName
		Else
			GetComputerName = "????"
		End If
	
		Set objNet = Nothing                        'Destroy the Object to free the Memory
	
	End Function

	'---------------------------------------------------------------------------------------------------
	' Initialize global varialbles for directories, etc.  Called at beginning of this transform
	'---------------------------------------------------------------------------------------------------
	Function Initialize(JobOrder, BinPath)
		On Error Resume Next
		Dim curDir					
		Dim fso
		Dim sErr
		
		'save job order
		jo = JobOrder
		'create FileSystemObject
		Set fso = CreateObject("Scripting.FileSystemObject")		
		xslDirPath = BinPath & "\"
		schemaPath = fso.GetAbsolutePathName(BinPath)
		cfgFilePath = fso.GetAbsolutePathName(BinPath & "\..\Projects\" & JobOrder) & "\joconfig.xml"
		cfgFolder = fso.GetAbsolutePathName(BinPath & "\..\Projects\" & JobOrder)
		dbPath = fso.GetAbsolutePathName(BinPath & "\..\DB\")
		worksheetPath = fso.GetAbsolutePathName(BinPath & "\..\IOWorksheets")		
		ActworksheetPath = fso.GetAbsolutePathName(BinPath & "\..\ActIOWorksheets")		
		projectsDirPath = fso.GetAbsolutePathName(BinPath & "\..\Projects")
		rootpath = fso.GetAbsolutePathName(BinPath & "\..")
		Initialize = ""
		
	End Function
	
	'---------------------------------------------------------------------------------------------------
	' Terminate			- Cleanup any objects, etc.  Called at end of this transform
	'---------------------------------------------------------------------------------------------------
	Sub Terminate
	End Sub
	
	'---------------------------------------------------------------------------------------------------
	' GetCfgFilePath		- Get configuration file path
	'---------------------------------------------------------------------------------------------------
	Function GetCfgFilePath
		GetCfgFilePath = cfgFilePath
	End Function
	
	'---------------------------------------------------------------------------------------------------
	' GetRootPath		- Get root working folder ..\JOCONFIG
	'---------------------------------------------------------------------------------------------------
	Function GetRootPath
		GetRootPath = rootpath
	End Function
	
	'---------------------------------------------------------------------------------------------------
	' GetDBPath		- Get database folder path
	'---------------------------------------------------------------------------------------------------
	Function GetDBPath
		GetDBPath = dbPath
	End Function

	'---------------------------------------------------------------------------------------------------
	' GetSchemaPath		- Get schema file path
	'---------------------------------------------------------------------------------------------------
	Function GetSchemaPath
		GetSchemaPath = schemaPath
	End Function

	'---------------------------------------------------------------------------------------------------
	' GetCfgFolderPath	- Get configuration folder path
	'---------------------------------------------------------------------------------------------------
	Function GetCfgFolderPath
		GetCfgFolderPath = cfgFolder
	End Function

	'---------------------------------------------------------------------------------------------------
	' GetXSLFilePath		- Get XSLT file path
	'---------------------------------------------------------------------------------------------------
	Function GetXSLFilePath
		GetXSLFilePath = xslDirPath
	End Function
	
	'---------------------------------------------------------------------------------------------------
	' GetWorkSheetPath		- Get IO Worksheet Folder file path
	'---------------------------------------------------------------------------------------------------
	Function GetWorkSheetPath
		GetWorkSheetPath = worksheetPath
	End Function
	
	'---------------------------------------------------------------------------------------------------
	' GetActWorkSheetPath		- Get Act IO Worksheet Folder file path
	'---------------------------------------------------------------------------------------------------
	Function GetActWorkSheetPath
		GetActWorkSheetPath = ActworksheetPath
	End Function

	'---------------------------------------------------------------------------------------------------
	' GetProjectDirPath	- Get Projects directory path
	'---------------------------------------------------------------------------------------------------
	Function GetProjectDirPath(proj)
		GetProjectDirPath = projectsDirPath &  "\" & proj
	End Function
		
	'---------------------------------------------------------------------------------------------------
	'qs - Quote string
	'---------------------------------------------------------------------------------------------------
	Function qs(s)
		qs = chr(34) & s & chr(34)
	End Function


	'---------------------------------------------------------------------------------------------------
	' CreateDirectory	- Create a directory
	'---------------------------------------------------------------------------------------------------
	Function CreateDirectory(DirPath)
		On Error Resume Next
		
		Dim fso				'WScript FileSystemObject
		Dim fldr				'New Directory
   		Dim ret				'Return (0 = OK, other = error number)
   		
   		Err.Clear
   		Set fso = CreateObject("Scripting.FileSystemObject")
   		
   		If Err.Number = 0 Then
 			If Not(fso.FolderExists(DirPath)) Then
   				Set fldr = fso.CreateFolder(DirPath)
   			End If
   		End If
   		
   		If Err.Number = 0 Then
   			ret = ""
   		Else
   		   	ret = Err.Number & " " & DirPath
   		End If
		
   		CreateDirectory = ret
	End Function
	
	'---------------------------------------------------------------------------------------------------
	' InitParamString		- Initialize parameter string
	'---------------------------------------------------------------------------------------------------
	Function InitParamString(s)
		sParam=s
		InitParamString = sParam
	End Function
	
	'---------------------------------------------------------------------------------------------------
	' AddToParamString
	'---------------------------------------------------------------------------------------------------
	Function AddToParamString(s)
		sParam=sParam & s
		AddToParamString = sParam
	End Function
	
	'---------------------------------------------------------------------------------------------------
	' GetParamString
	'---------------------------------------------------------------------------------------------------
	Function GetParamString()
		GetParamString = sParam
	End Function


	'---------------------------------------------------------------------------------------------------
	' FileName - Gets file or folder name
	'
	'	Args
	'	src		- source file or folder path
	'	
	'	Returns
	'	file name or null string if error
	'---------------------------------------------------------------------------------------------------
	Function FileName(src)
	
   		Dim fso					' file system object
   		Dim f					' file
   		Dim fn	 				' file or folder name
   		
   		On Error Resume Next
     		   		
   		Set fso = CreateObject("Scripting.FileSystemObject")
   		
   		'Check for file existence
   		If (fso.FileExists(src)) Then
			Set f = fso.GetFile(src)
		ElseIf (fso.FolderExists(src)) Then
			Set f = fso.GetFolder(src)
		End If
			
		fn = f.name
 
  		If Err.Number = 0 Then
   			FileName = fn
   		Else
   			FileName = Err.Description & " - " & src
   		End If
   		
	End Function
		'---------------------------------------------------------------------------------------------------
	' CheckFileExists - Checks if a file / folder exists
	'
	'	Args
	'	src		- source file or folder path
	'	
	'	Returns
	'	1 if found or 0 if error
	'---------------------------------------------------------------------------------------------------
	Function CheckFileExists(src)
	
   		Dim fso				' file system object
   		Dim f					' file
   		Dim fn	 				' file or folder name
   		
   		On Error Resume Next
     		   		
   		Set fso = CreateObject("Scripting.FileSystemObject")
   		
   		'Check for file existence
   		If (fso.FileExists(src)) Then
			Set f = fso.GetFile(src)
		ElseIf (fso.FolderExists(src)) Then
			Set f = fso.GetFolder(src)
		End If
			
		fn = f.name
 
  		If Err.Number = 0 Then
   			CheckFileExists = 1
   		Else
   			CheckFileExists = 0
   		End If
   		
	End Function



	'---------------------------------------------------------------------------------------------------
	' SetFileReadOnly
	'
	'	Args
	'	src		- file to set to read-only
	'	
	'	Returns
	'	file attributes or error string
	'---------------------------------------------------------------------------------------------------
	Function SetFileReadOnly(src)
	
   		Dim fso					' file system object
   		Dim f					' file
   		
   		On Error Resume Next
     		   		
   		Set fso = CreateObject("Scripting.FileSystemObject")
   		
   		'Check for file existence
   		If (fso.FileExists(src)) Then
			Set f = fso.GetFile(src)
		End If
		
		'Set read-only bit
		f.attributes = f.attributes or 1
			
  		If Err.Number = 0 Then
   			SetFileReadOnly = f.attributes
   		Else
   			SetFileReadOnly = Err.Description & " - " & src
   		End If
   		
	End Function

	'---------------------------------------------------------------------------------------------------
	' ClearFileReadOnly
	'
	'	Args
	'	src		- file to clear to read-only attribute
	'	
	'	Returns
	'	file attributes or error string
	'---------------------------------------------------------------------------------------------------
	Function ClearFileReadOnly(src)
	
   		Dim fso					' file system object
   		Dim f					' file
   		
   		On Error Resume Next
     		   		
   		Set fso = CreateObject("Scripting.FileSystemObject")
   		
   		'Check for file existence
   		If (fso.FileExists(src)) Then
			Set f = fso.GetFile(src)
		End If
		
		'Clear read-only bit if set
		If f.attributes and 1 then
			f.attributes = f.attributes - 1
		End If
			
  		If Err.Number = 0 Then
   			ClearFileReadOnly = f.attributes
   		Else
   			ClearFileReadOnly = Err.Description & " - " & src
   		End If
   		
	End Function
	
	
	'---------------------------------------------------------------------------------------------------
	' CopyFile - Copies a file or folder
	'
	'	Args
	'	src		- source file or folder path
	'	dst		- destination file or folder path	
	'	
	'	Returns
	'	null string or error description
	'---------------------------------------------------------------------------------------------------
	Function CopyFIle(src, dst)
	
   		Dim fso					' file system object
   		Dim srcfile				' source file
   		
   		On Error Resume Next
     		   		
   		Set fso = CreateObject("Scripting.FileSystemObject")
   		
   		'Check for file in both directories
   		If (fso.FileExists(src)) Then
			Set srcfile = fso.GetFile(src)
		ElseIf(fso.FolderExists(src)) Then
			Set srcfile = fso.GetFolder(src)
		End If
		
		srcfile.copy(dst)

  		If Err.Number = 0 Then
   			CopyFile = ""
   		Else
   			CopyFile = Err.Description
   		End If
   		
	End Function


	'---------------------------------------------------------------------------------------------------
	' FilePath - Returns path of file (checks in dir1 and dir2), returns path or null string if not found
	'
	'	Args
	'	file 	- name of file to look for
	'	dir1	- path of first directory to search
	'	dir2	- path of second directory to search
	'	
	'	Returns
	'	path of file or null string
	'---------------------------------------------------------------------------------------------------
	Function FilePath(file, dir1, dir2)
	
   		Dim fso					' file system object
   		Dim p1					' file path to check in first directory
   		Dim p2					' file path to check in second directory 
   		Dim retval				' returned path value
   		
   		On Error Resume Next
     		
   		p1 = dir1 & "\" & file
   		p2 = dir2 & "\" & file
   		
   		Set fso = CreateObject("Scripting.FileSystemObject")
   		
   		'Check for file in both directories
   		If (fso.FileExists(p1)) Then
      			retval = p1
   		ElseIf (fso.FileExists(p2)) Then
     			retval = p2
     		Else
     			retval = ""
  		End If
  		
  		If Err.Number = 0 Then
   			FilePath = retval
   		Else
   			FilePath = ""
   		End If
   		
	End Function

	'---------------------------------------------------------------------------------------------------
	' XSLTransform - Invoke XSLT transform to generate output file
	'---------------------------------------------------------------------------------------------------
	Function XSLTransform(inXMLPath, xfXSLPath, outXMLPath, ParamString)
		On Error Resume Next
		
		Dim WshShell						'Windows scripting host shell object
		Dim oExec	
		Dim scmdArgs						'msxsl command line for shell execution
		
		Set WshShell = CreateObject("WScript.Shell")
		
		If Err.Number = 0 Then 
			scmdArgs = ""
			scmdArgs = scmdArgs & qs(xslDirPath & "\msxsl") & " " 
			scmdArgs = scmdArgs & qs(inXMLPath) & " " 
			scmdArgs = scmdArgs & qs(xfXSLPath)
			scmdArgs = scmdArgs & " -o " & qs(outXMLPath) 
			scmdArgs = scmdArgs & " " & ParamString
			
			If Err.Number = 0 Then
				'minimized window, wait on return
				Set oExec = WshShell.Run(scmdArgs,7,true)
			Else
				XSLTransform = Err.Description & " " & outXMLPath
				Exit Function
			End If
			
		Else
			scmdArgs = "CreateObject(WScript.Shell) Error in XSLTransform"
		End If
		
		
		XSLTransform = CStr(scmdArgs)
	End Function


	'---------------------------------------------------------------------------------------------------
	' RunExe - Run an executable
	'---------------------------------------------------------------------------------------------------
	Function RunExe(exePath, ParamString)
		On Error Resume Next
		
		Dim WshShell						'Windows scripting host shell object
		Dim oExec	
		Dim scmdArgs						'msxsl command line for shell execution
		
		Set WshShell = CreateObject("WScript.Shell")
		
		If Err.Number = 0 Then 
			scmdArgs = qs(exePath)
			scmdArgs = scmdArgs & " " & ParamString
			
			If Err.Number = 0 Then
				'minimized window, wait on return
				Set oExec = WshShell.Run(scmdArgs,7,true)
			Else
				RunExe = Err.Description & " " & outXMLPath
				Exit Function
			End If
			
		Else
			scmdArgs = "CreateObject(WScript.Shell) Error in XSLTransform"
		End If
		
		
		RunExe = CStr(scmdArgs)
	End Function

	'---------------------------------------------------------------------------------------------------
	' GetCurrentTime- Returns the current time
	'---------------------------------------------------------------------------------------------------
	Function GetCurrentTime()
		On Error Resume Next
		GetCurrentTime= CStr(Now())
	End Function
  
  '---------------------------------------------------------------------------------------------------
	' RemoveDuplicity - Remove duplicit strings from input string separated by ';'
	'---------------------------------------------------------------------------------------------------
	Function RemoveDuplicitStrings(inputString)
		On Error Resume Next
    
    Dim stringArray
    Dim outputString
    Dim str
    outputString = ""
       
    stringArray = Split(inputString, ";")
    For Each str In stringArray
      If InStr(outputString, str) = 0 Then
        outputString = outputString & str & ";"
      End If  
    Next
		RemoveDuplicitStrings = outputString
	End Function

	]]>

	</msxsl:script>


	<!-- 
	******************************************************
	Global Templates
	******************************************************		
	-->
	<xsl:template name="CDPackageNumber">
		<xsl:param name="CDID"/>
			<xsl:for-each select="/xml/rs:data/z:row/tblClassicCDControls">
				<xsl:choose>
					<xsl:when test="$CDID = ./@CDControlID">
						<xsl:value-of select="position()"/>
					</xsl:when>
					<xsl:otherwise>			
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
	</xsl:template>
			
	<xsl:template name="ScannerNumber">
		<xsl:param name="ScannerID"/>
		<xsl:value-of select="/xml/rs:data/z:row/tblScanners[@ScannerID=$ScannerID]/@ScannerNumber"/>
	</xsl:template>

</xsl:stylesheet>
