<?xml version="1.0" encoding="UTF-8"?>

<!-- Measurement.xslt
Description:
This file contains measurement specific templates for generating measurement related outputs with XSLT.

Notes:
This file is compatible with the msxml / msxsl 4.0 XML parser and transform tools.

History:
2001-12-18 		Original									R. Trent Garverick
2002-09-10			Corrected MW nickname					rtg
2002-09-27			Added object name also used in grades			WLH
2002-10-07			Completed MeasCtrlNames				RTG
2002-11-18			Added MeasDependPriority Template		RTG
2002-12-06			Added Scanner type variables			RTG
2003-05-12			Added Tissue Weight support			RTG
2003-09-11	     	Ensured Tissue Weight, Fiber Weight and IR Coat Moisture have unique IDs RTG
2003-09-12			Added SP_OPCSensorDeviceID template  RTG
2003-09-15	 		Added IR Coat Weight and Chalk, Clay, Latex measurements 	RTG
2003-09-23			Added TLName attribute in AddMeasurement template		RTG
2003-04-22		
2003-08-16			Removed MeasNameRsdID template, RSCID now in joconfig.xml	RTG
2008-06-04			Integrated MCD: added Difference and Twist measurements		AZ
2008-11-27    	    Added Optical Caliper support 	FJ
2009-09-09         Added Z measurement type for OC. Changed OC related name types for conformity.  FJ
2009-09-10         Added HPIR-T moisture as new measurement type.  FJ
2012-04-06		   Added HPIR-BW Moisture, Fiber Weighe and Basis Weight type.		PJL
2012-09-07         Added Macro Surface Variation Properties and Micro Surface Variation Properties		RCH
2022-03-03			Added External MD Measurement support	PT
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	
	<!-- *********************************************************************************************************************
		Quality Control System Scanner Types
		
		*********************************************************************************************************************
	-->
		<xsl:variable name="SP1200" select="2"/>
		<xsl:variable name="SP700" select="3"/>
		<xsl:variable name="SPReflection" select="4"/>
		<xsl:variable name="NA1200" select="5"/>
		<xsl:variable name="NA700" select="6"/>
		<xsl:variable name="NAReflection" select="7"/>
		<xsl:variable name="NP800" select="8"/>

	<!-- *********************************************************************************************************************
		Quality Control System Sensor Types
		
		Sensors can consist of 1..n sub-measurements
		*********************************************************************************************************************
	-->
		<xsl:variable name="S_AirColumn" select="1"/>
		<xsl:variable name="S_ApparentDensity" select="2"/>
		<xsl:variable name="S_Ash" select="3"/>
		<xsl:variable name="S_OptiPak" select="4"/>
		<xsl:variable name="S_Caliper" select="5"/>
		<xsl:variable name="S_ColorTop" select="6"/>
		<xsl:variable name="S_ColorBottom" select="7"/>
		<xsl:variable name="S_ConditionedWeight" select="8"/>
		<xsl:variable name="S_GlossTop" select="9"/>
		<xsl:variable name="S_GlossBottom" select="28"/>	
		<xsl:variable name="S_IRMoisture" select="10"/>
		<xsl:variable name="S_MicrowaveMoisture" select="11"/>
		<xsl:variable name="S_SheetTemperature" select="14"/>
		<xsl:variable name="S_UniqueSP" select="15"/>
		<xsl:variable name="S_BasisWeight" select="16"/>
		<xsl:variable name="S_XRayWeight" select="17"/>
		<xsl:variable name="S_IRCoatWeightTop" select="18"/>
		<xsl:variable name="S_IRCoatWeightBottom" select="19"/>
		<xsl:variable name="S_FiberOrientationTop" select="20"/>
		<xsl:variable name="S_FiberOrientationBottom" select="21"/>
		<xsl:variable name="S_CoatWeight" select="22"/>
		<xsl:variable name="S_WeightCompensatedMoisture" select="24"/>
		<xsl:variable name="S_WaterBalance" select="25"/>
		<xsl:variable name="S_TissueWeight" select="26"/>
		<xsl:variable name="S_UniqueCalcMeas" select="27"/>
		<xsl:variable name="S_Difference" select="29"/>
		<xsl:variable name="S_TwistIndex" select="30"/>
		<xsl:variable name="S_Ratio" select="31"/>
		<xsl:variable name="S_OpticalCaliper" select="32"/>
		<xsl:variable name="S_HPIRTMoisture" select="34"/>
		<xsl:variable name="S_HPIRWeight" select="35"/>
		<xsl:variable name="S_SurfaceVariation" select="36"/>
		<xsl:variable name="S_HPColorTop" select="37"/>
		<xsl:variable name="S_HPColorBottom" select="38"/>
		<xsl:variable name="S_HPColorProfileTop" select="39"/>
		<xsl:variable name="S_HPColorProfileBottom" select="40"/>
		<xsl:variable name="S_HPIRRMoisture" select="41"/>
	<!-- *********************************************************************************************************************
		Quality Control System Measurement Types
		
		Types > Use the sensor type to determine measurements with top / bottom A/B designators and for
		measurements with subtypes.
		
		Type reported is type div 1000.  For example the actual system type for both color top and color bottom is 6.
		*********************************************************************************************************************
	-->
		<xsl:variable name="AirColumn" select="1"/>
		<xsl:variable name="ApparentDensity" select="2"/>
		<xsl:variable name="Ash" select="3"/>
		<xsl:variable name="Brightness" select="4"/>
		<xsl:variable name="Caliper" select="5"/>
		<xsl:variable name="Color" select="6"/>
		<xsl:variable name="ConditionedWeight" select="11"/>
		<xsl:variable name="Formation" select="13"/>
		<xsl:variable name="Gloss" select="14"/>
		<xsl:variable name="Moisture" select="16"/>
		<xsl:variable name="MicrowaveMoisture" select="17"/>
		<xsl:variable name="Opacity" select="18"/>
		<xsl:variable name="Temperature" select="21"/>
		<xsl:variable name="Unique" select="22"/>
		<xsl:variable name="Weight" select="23"/>
		<xsl:variable name="XRay" select="24"/>
		<xsl:variable name="CalcMeas" select="25"/>
		<xsl:variable name="Ratio" select="26"/>
		<xsl:variable name="FiberOrientationAngle" select="29"/>
		<xsl:variable name="FiberOrientationRatio" select="30"/>
		<xsl:variable name="IRCWClay" select="27"/>
		<xsl:variable name="IRCWLatex" select="28"/>
		<xsl:variable name="IRCWChalk" select="31"/>
		<xsl:variable name="IRCoatMoisture" select="32"/>
		<xsl:variable name="HiddenCalcMeas" select="33"/>
		<!-- These are here to represent a combined IRCoatWeight Measurement -->
		<xsl:variable name="IRCoatWeightTop" select="34"/>
		<xsl:variable name="IRCoatWeightBottom" select="35"/>
		<!-- These are here to represent optical caliper Measurement -->
		<xsl:variable name="OpticalCaliper" select="36"/>
		<xsl:variable name="OpticalCaliperRO" select="37"/>
		<xsl:variable name="OpticalCaliperOP" select="38"/>
		<xsl:variable name="OpticalCaliperMA" select="39"/>
		<xsl:variable name="OpticalCaliperMD" select="40"/>
		<xsl:variable name="OpticalCaliperCD" select="41"/>
		<xsl:variable name="OpticalCaliperZD" select="42"/>
		<!-- This is the HPIR-T Moisture Sensor -->
		<xsl:variable name="HPIRTMoisture" select="43"/>
		<!-- This is the HPIR-BW Weight Sensor -->
		<xsl:variable name="HPIRBWMoisture" select="44"/>
		<xsl:variable name="HPIRBWFiberWeight" select="45"/>
		<xsl:variable name="HPIRBWBasisWeight" select="46"/>
				
		<!-- This is the additional measurements for the Optical Caliper Sensor -->
		<xsl:variable name="SurfacePropertiesMaV" select="47"/>
		<xsl:variable name="SurfacePropertiesMiV" select="48"/>
		<xsl:variable name="HPColor" select="49"/>
	<xsl:variable name="HPColorProfileaStar" select="50"/>
	<xsl:variable name="HPColorProfilebStar" select="51"/>
	<xsl:variable name="HPColorProfileLStar" select="52"/>
	<xsl:variable name="HPColorProfileBrightness" select="53"/>
	<xsl:variable name="HPColorProfileUVBrightness" select="54"/>
	<!-- This is the HPIR-R Moisture Sensor -->
	<xsl:variable name="HPIRRMoisture" select="55"/>
	<xsl:variable name="ACAPorosity" select="56"/>
	<xsl:variable name="ExternalMD" select="57"/>
	<!-- *********************************************************************************************************************
		Quality Control System Coat Types
		
		*********************************************************************************************************************
	-->
	<xsl:variable name="CT_Default" select="0"/>
	<xsl:variable name="CT_BasisWeightDifference" select="1"/>
	<xsl:variable name="CT_DryWeightDifference" select="2"/>
	<xsl:variable name="CT_XrayWeightDifference" select="3"/>
	<xsl:variable name="CT_IRSingleCoat" select="4"/>
	<xsl:variable name="CT_IRDualCoat" select="5"/>
	<xsl:variable name="CT_IRPressCoat" select="6"/>
	<!-- *********************************************************************************************************************
		External measurement types

		*********************************************************************************************************************	
	-->
	<xsl:variable name="ExternalMeasManualAC800MD" select="1"/>
	<xsl:variable name="ExternalMeasOPCAC800MD" select="2"/>
	<xsl:variable name="ExternalMeasACAPorosity" select="3"/>
  <xsl:variable name="ExternalMeasOSSEngine" select="4"/>
	<!-- *********************************************************************************************************************
		SP_Nickname
		
		Returns measurement nickname (WT, MO, CA, ...) for measurement type passed as parameter
		*********************************************************************************************************************	
	-->
	<xsl:template name="SP_Nickname">
		<xsl:param name="SensorType"/>
		<xsl:param name="MeasurementType"/>
		<xsl:param name="MeasurementNumber"/>
		<xsl:choose>
			<xsl:when test="$MeasurementType = $AirColumn">
				<xsl:value-of select="concat('AC', $MeasurementNumber)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $ApparentDensity">
				<xsl:value-of select="concat('AP', $MeasurementNumber)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $Ash">
				<xsl:value-of select="concat('AS', $MeasurementNumber)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $Brightness">
				<xsl:value-of select="concat('BR', $MeasurementNumber)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $Caliper">
				<xsl:value-of select="concat('CA', $MeasurementNumber)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliper">
				<xsl:value-of select="concat('OC', $MeasurementNumber)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperMA">
				<xsl:value-of select="concat('OM', $MeasurementNumber)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperOP">
				<xsl:value-of select="concat('OO', $MeasurementNumber)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperMD">
				<xsl:value-of select="concat('OY', $MeasurementNumber)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperCD">
				<xsl:value-of select="concat('OX', $MeasurementNumber)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperZD">
				<xsl:value-of select="concat('OZ', $MeasurementNumber)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperRO">
				<xsl:value-of select="concat('OR', $MeasurementNumber)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $SurfacePropertiesMaV">
				<xsl:value-of select="concat('OD', $MeasurementNumber)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $SurfacePropertiesMiV">
				<xsl:value-of select="concat('OV', $MeasurementNumber)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $Color">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_ColorTop">CLT</xsl:when>
					<xsl:when test="$SensorType = $S_ColorBottom">CLB</xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$MeasurementType = $ConditionedWeight">
				<xsl:value-of select="concat('CW', $MeasurementNumber)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $Formation">
				<xsl:value-of select="concat('FO', $MeasurementNumber)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $Gloss">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_GlossTop">GLT</xsl:when>
					<xsl:when test="$SensorType = $S_GlossBottom">GLB</xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$MeasurementType = $Moisture">
				<xsl:value-of select="concat('MO', $MeasurementNumber)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $HPIRTMoisture">
				<xsl:value-of select="concat('MX', $MeasurementNumber)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $HPIRRMoisture">
				<xsl:value-of select="concat('MR', $MeasurementNumber)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $HPIRBWMoisture">
				<xsl:value-of select="concat('MX', $MeasurementNumber)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $HPIRBWFiberWeight">
				<xsl:value-of select="concat('FX', $MeasurementNumber)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $HPIRBWBasisWeight">
				<xsl:value-of select="concat('BX', $MeasurementNumber)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $MicrowaveMoisture">
				<xsl:value-of select="concat('MW', $MeasurementNumber)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $Opacity">
				<xsl:value-of select="concat('OP', $MeasurementNumber)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $Temperature">
				<xsl:value-of select="concat('ST', $MeasurementNumber)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $Unique">
				<xsl:value-of select="concat('UNQ', $MeasurementNumber)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $Weight">
				<xsl:value-of select="concat('WT', $MeasurementNumber)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $XRay">
				<xsl:value-of select="concat('XR', $MeasurementNumber)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $Ratio">
				<xsl:value-of select="concat('RT', $MeasurementNumber)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $FiberOrientationAngle">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_FiberOrientationTop">FIBORTOPANG</xsl:when>
					<xsl:when test="$SensorType = $S_FiberOrientationBottom">FIBORBOTANG</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $FiberOrientationRatio">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_FiberOrientationTop">FIBORTOPRTO</xsl:when>
					<xsl:when test="$SensorType = $S_FiberOrientationBottom">FIBORBOTRTO</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $IRCWClay">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_IRCoatWeightTop">CWTY</xsl:when>
					<xsl:when test="$SensorType = $S_IRCoatWeightBottom">CWBY</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $IRCWChalk">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_IRCoatWeightTop">CWTK</xsl:when>
					<xsl:when test="$SensorType = $S_IRCoatWeightBottom">CWBK</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $IRCWLatex">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_IRCoatWeightTop">CWTL</xsl:when>
					<xsl:when test="$SensorType = $S_IRCoatWeightBottom">CWBL</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $IRCoatMoisture">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_IRCoatWeightTop">CWTM</xsl:when>
					<xsl:when test="$SensorType = $S_IRCoatWeightBottom">CWBM</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $CalcMeas">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_CoatWeight">
						<xsl:value-of select="concat('CCW', $MeasurementNumber)"/>
					</xsl:when>
					<xsl:when test="$SensorType = $S_WaterBalance">
						<xsl:value-of select="concat('WB', $MeasurementNumber)"/>
					</xsl:when>
					<xsl:when test="$SensorType = $S_TissueWeight">
						<xsl:value-of select="concat('TW', $MeasurementNumber)"/>
					</xsl:when>
					<xsl:when test="$SensorType = $S_UniqueCalcMeas">
						<xsl:value-of select="concat('UCM', $MeasurementNumber)"/>
					</xsl:when>
					<xsl:when test="$SensorType = $S_Difference">
						<xsl:value-of select="concat('DF', $MeasurementNumber)"/>
					</xsl:when>
					<xsl:when test="$SensorType = $S_TwistIndex">
						<xsl:value-of select="concat('TI', $MeasurementNumber)"/>
					</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $HiddenCalcMeas">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_WeightCompensatedMoisture">
						<xsl:value-of select="concat('WCM', $MeasurementNumber)"/>
					</xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$MeasurementType = $IRCoatWeightTop">CWT</xsl:when>
			<xsl:when test="$MeasurementType = $IRCoatWeightBottom">CWB</xsl:when>
			<xsl:when test="$MeasurementType = $HPColor">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_HPColorTop">CLT</xsl:when>
					<xsl:when test="$SensorType = $S_HPColorBottom">CLB</xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$MeasurementType = $HPColorProfileaStar">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_HPColorProfileTop">
						<xsl:value-of select="concat('CLT_A', $MeasurementNumber)"/>
					</xsl:when>
					<xsl:when test="$SensorType = $S_HPColorProfileBottom">
						<xsl:value-of select="concat('CLB_A', $MeasurementNumber)"/>
					</xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$MeasurementType = $HPColorProfilebStar">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_HPColorProfileTop">
						<xsl:value-of select="concat('CLT_B', $MeasurementNumber)"/>
					</xsl:when>
					<xsl:when test="$SensorType = $S_HPColorProfileBottom">
						<xsl:value-of select="concat('CLB_B', $MeasurementNumber)"/>
					</xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$MeasurementType = $HPColorProfileLStar">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_HPColorProfileTop">
						<xsl:value-of select="concat('CLT_L', $MeasurementNumber)"/>
					</xsl:when>
					<xsl:when test="$SensorType = $S_HPColorProfileBottom">
						<xsl:value-of select="concat('CLB_L', $MeasurementNumber)"/>
					</xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$MeasurementType = $HPColorProfileBrightness">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_HPColorProfileTop">
						<xsl:value-of select="concat('CLT_BR', $MeasurementNumber)"/>
					</xsl:when>
					<xsl:when test="$SensorType = $S_HPColorProfileBottom">
						<xsl:value-of select="concat('CLB_BR', $MeasurementNumber)"/>
					</xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$MeasurementType = $HPColorProfileUVBrightness">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_HPColorProfileTop">
						<xsl:value-of select="concat('CLT_UVBR', $MeasurementNumber)"/>
					</xsl:when>
					<xsl:when test="$SensorType = $S_HPColorProfileBottom">
						<xsl:value-of select="concat('CLB_UVBR', $MeasurementNumber)"/>
					</xsl:when>
				</xsl:choose>
			</xsl:when>
			<!-- External MD Measurements-->
			<xsl:when test="$MeasurementType = $ExternalMD">
				<xsl:value-of select="concat('EX_MD', $MeasurementNumber)"/>
			</xsl:when>			
			<!-- Unknown -->
			<xsl:otherwise>
				<xsl:value-of select="concat('UNK', $MeasurementNumber)"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>


	<!-- *********************************************************************************************************************
		MeasCtrllName
		
		Returns measurement control name (BW11, MO21, CA, ...) for measurement type passed as parameter
		The measurement control name is created as follows:
		
		first two characters 	measurement dependent
		first digit				scanner number
		2'nd digit				measurement type instance on that scanner
		*********************************************************************************************************************	
	-->
	<xsl:template name="MeasCtrlName">
		<xsl:param name="SensorType"/>
		<xsl:param name="MeasurementType"/>
		<xsl:param name="ScannerNumber"/>
		<xsl:param name="MeasurementNumber"/>
		
		<!-- create two digit scanner - instance string -->
		<xsl:variable name="mnb">
			<xsl:value-of select="concat(format-number($ScannerNumber, '0'), format-number($MeasurementNumber, '0'))"/>
		</xsl:variable>
		<xsl:choose>
			<xsl:when test="$MeasurementType = $AirColumn">
				<xsl:value-of select="concat('AC', $mnb)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $ApparentDensity">
				<xsl:value-of select="concat('AP', $mnb)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $Ash">
				<xsl:value-of select="concat('AS', $mnb)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $Brightness">
				<xsl:value-of select="concat('BR', $mnb)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $Caliper">
				<xsl:value-of select="concat('CA', $mnb)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliper">
				<xsl:value-of select="concat('OC', $mnb)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperMA">
				<xsl:value-of select="concat('OM', $mnb)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperOP">
				<xsl:value-of select="concat('OO', $mnb)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperMD">
				<xsl:value-of select="concat('OY', $mnb)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperCD">
				<xsl:value-of select="concat('OX', $mnb)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperZD">
				<xsl:value-of select="concat('OZ', $mnb)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperRO">
				<xsl:value-of select="concat('OR', $mnb)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $SurfacePropertiesMaV">
				<xsl:value-of select="concat('OD', $mnb)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $SurfacePropertiesMiV">
				<xsl:value-of select="concat('OV', $mnb)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $ConditionedWeight">
				<xsl:value-of select="concat('CW', $mnb)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $Formation">
				<xsl:value-of select="concat('FO', $mnb)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $Gloss">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_GlossTop">
						<xsl:value-of select="concat('GT', $mnb)"/>
					</xsl:when>
					<xsl:when test="$SensorType = $S_GlossBottom">
						<xsl:value-of select="concat('GB', $mnb)"/>
					</xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$MeasurementType = $Moisture">
				<xsl:value-of select="concat('MO', $mnb)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $MicrowaveMoisture">
				<xsl:value-of select="concat('MO', $mnb)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $HPIRTMoisture">
				<xsl:value-of select="concat('MX', $mnb)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $HPIRRMoisture">
				<xsl:value-of select="concat('MR', $mnb)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $HPIRBWMoisture">
				<xsl:value-of select="concat('MX', $mnb)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $HPIRBWFiberWeight">
				<xsl:value-of select="concat('FX', $mnb)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $HPIRBWBasisWeight">
				<xsl:value-of select="concat('BX', $mnb)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $Opacity">
				<xsl:value-of select="concat('OP', $mnb)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $Temperature">
				<xsl:value-of select="concat('ST', $mnb)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $Unique">
				<xsl:value-of select="concat('UQ', $mnb)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $Weight">
				<xsl:value-of select="concat('BW', $mnb)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $XRay">
				<xsl:value-of select="concat('XR', $mnb)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $Ratio">
				<xsl:value-of select="concat('RT', $mnb)"/>
			</xsl:when>
			<xsl:when test="$MeasurementType = $FiberOrientationAngle">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_FiberOrientationTop">
						<xsl:value-of select="concat('AT', $mnb)"/>
					</xsl:when>
					<xsl:when test="$SensorType = $S_FiberOrientationBottom">
						<xsl:value-of select="concat('AB', $mnb)"/>
					</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $FiberOrientationRatio">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_FiberOrientationTop">
						<xsl:value-of select="concat('RT', $mnb)"/>
					</xsl:when>
					<xsl:when test="$SensorType = $S_FiberOrientationBottom">
						<xsl:value-of select="concat('RB', $mnb)"/>
					</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $IRCWClay">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_IRCoatWeightTop">
						<xsl:value-of select="concat('CY', $mnb)"/>
					</xsl:when>
					<xsl:when test="$SensorType = $S_IRCoatWeightBottom">
						<xsl:value-of select="concat('CY', $mnb)"/>
					</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $IRCWChalk">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_IRCoatWeightTop">
						<xsl:value-of select="concat('CK', $mnb)"/>
					</xsl:when>
					<xsl:when test="$SensorType = $S_IRCoatWeightBottom">
						<xsl:value-of select="concat('CK', $mnb)"/>
					</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $IRCWLatex">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_IRCoatWeightTop">
						<xsl:value-of select="concat('CL', $mnb)"/>
					</xsl:when>
					<xsl:when test="$SensorType = $S_IRCoatWeightBottom">
						<xsl:value-of select="concat('CL', $mnb)"/>
					</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $IRCoatMoisture">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_IRCoatWeightTop">
						<xsl:value-of select="concat('CM', $mnb)"/>
					</xsl:when>
					<xsl:when test="$SensorType = $S_IRCoatWeightBottom">
						<xsl:value-of select="concat('CM', $mnb)"/>
					</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $CalcMeas">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_CoatWeight">
						<xsl:value-of select="concat('CT', $mnb)"/>
					</xsl:when>
					<xsl:when test="$SensorType = $S_WaterBalance">
						<xsl:value-of select="concat('WB', $mnb)"/>
					</xsl:when>
					<xsl:when test="$SensorType = $S_TissueWeight">
						<xsl:value-of select="concat('TW', $mnb)"/>
					</xsl:when>
					<xsl:when test="$SensorType = $S_UniqueCalcMeas">
						<xsl:value-of select="concat('UC', $mnb)"/>
					</xsl:when>
					<xsl:when test="$SensorType = $S_Difference">
						<xsl:value-of select="concat('DF', $mnb)"/>
					</xsl:when>
					<xsl:when test="$SensorType = $S_TwistIndex">
						<xsl:value-of select="concat('TI', $mnb)"/>
					</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $HiddenCalcMeas">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_WeightCompensatedMoisture">
						<xsl:value-of select="concat('WC', $mnb)"/>
					</xsl:when>
				</xsl:choose>
			</xsl:when>	
			<!-- Color Measurement cannot be assigned to MD or CD Control 
			<xsl:when test="$MeasurementType = $Color"></xsl:when>			
			-->
			<xsl:when test="$MeasurementType = $HPColorProfileaStar">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_HPColorProfileTop">
						<xsl:value-of select="concat('CLT_A', $mnb)"/>
					</xsl:when>
				</xsl:choose>
				<xsl:choose>
					<xsl:when test="$SensorType = $S_HPColorProfileBottom">
						<xsl:value-of select="concat('CLB_A', $mnb)"/>
					</xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$MeasurementType = $HPColorProfilebStar">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_HPColorProfileTop">
						<xsl:value-of select="concat('CLT_B', $mnb)"/>
					</xsl:when>
				</xsl:choose>
				<xsl:choose>
					<xsl:when test="$SensorType = $S_HPColorProfileBottom">
						<xsl:value-of select="concat('CLB_B', $mnb)"/>
					</xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$MeasurementType = $HPColorProfileLStar">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_HPColorProfileTop">
						<xsl:value-of select="concat('CLT_L', $mnb)"/>
					</xsl:when>
				</xsl:choose>
				<xsl:choose>
					<xsl:when test="$SensorType = $S_HPColorProfileBottom">
						<xsl:value-of select="concat('CLB_L', $mnb)"/>
					</xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$MeasurementType = $HPColorProfileBrightness">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_HPColorProfileTop">
						<xsl:value-of select="concat('CLT_BR', $mnb)"/>
					</xsl:when>
				</xsl:choose>
				<xsl:choose>
					<xsl:when test="$SensorType = $S_HPColorProfileBottom">
						<xsl:value-of select="concat('CLB_BR', $mnb)"/>
					</xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$MeasurementType = $HPColorProfileUVBrightness">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_HPColorProfileTop">
						<xsl:value-of select="concat('CLT_UVBR', $mnb)"/>
					</xsl:when>
				</xsl:choose>
				<xsl:choose>
					<xsl:when test="$SensorType = $S_HPColorProfileBottom">
						<xsl:value-of select="concat('CLB_UVBR', $mnb)"/>
					</xsl:when>
				</xsl:choose>
			</xsl:when>
			<!-- External MD Measurements -->
			<xsl:when test="$MeasurementType = $ExternalMD">
				<xsl:value-of select="concat('EXT',format-number($MeasurementNumber, '0'))"/>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	


	<!-- *********************************************************************************************************************
		MeasUnitsRscID
		
		Returns Measurement Units Resource ID for measurement type passed as parameter
		*********************************************************************************************************************	
	-->
	<xsl:template name="MeasUnitsRscId">
		<xsl:param name="SensorType"/>
		<xsl:param name="MeasurementType"/>
		<xsl:variable name="FrameBaseLine">
			<xsl:value-of select="14560 + (count(preceding::tblScanners) * 31)"/>
		</xsl:variable>
		<xsl:choose>
			<xsl:when test="$MeasurementType = $AirColumn">14002</xsl:when>
			<xsl:when test="$MeasurementType = $ApparentDensity">14004</xsl:when>
			<xsl:when test="$MeasurementType = $Ash">14006</xsl:when>
			<xsl:when test="$MeasurementType = $Brightness">14010</xsl:when>
			<xsl:when test="$MeasurementType = $Caliper">14012</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliper">14012</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperMA">14012</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperOP">14012</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperCD">14012</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperMD">14012</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperZD">14012</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperRO">14012</xsl:when>	
			<xsl:when test="$MeasurementType = $SurfacePropertiesMaV">14012</xsl:when>
			<xsl:when test="$MeasurementType = $SurfacePropertiesMiV">14012</xsl:when>			
			<xsl:when test="$MeasurementType = $Color">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_ColorTop">14022</xsl:when>
					<xsl:when test="$SensorType = $S_ColorBottom">14022</xsl:when>
				</xsl:choose>
			</xsl:when>	
			<xsl:when test="$MeasurementType = $ConditionedWeight">14008</xsl:when>			
			<xsl:when test="$MeasurementType = $Formation">14036</xsl:when>	
			<xsl:when test="$MeasurementType = $Gloss">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_GlossTop">14038</xsl:when>
					<xsl:when test="$SensorType = $S_GlossBottom">14038</xsl:when>
				</xsl:choose>
			</xsl:when>	
			<xsl:when test="$MeasurementType = $Moisture">14048</xsl:when>			
			<xsl:when test="$MeasurementType = $MicrowaveMoisture">14048</xsl:when>			
			<xsl:when test="$MeasurementType = $HPIRTMoisture">14048</xsl:when>
			<xsl:when test="$MeasurementType = $HPIRRMoisture">14048</xsl:when>
			<xsl:when test="$MeasurementType = $HPIRBWMoisture">14048</xsl:when> 
			<xsl:when test="$MeasurementType = $HPIRBWFiberWeight">14008</xsl:when> 
			<xsl:when test="$MeasurementType = $HPIRBWBasisWeight">14008</xsl:when> 
			<xsl:when test="$MeasurementType = $Opacity">14052</xsl:when>			
			<xsl:when test="$MeasurementType = $Temperature">14056</xsl:when>			
			<xsl:when test="$MeasurementType = $Unique">14064</xsl:when>	
			<xsl:when test="$MeasurementType = $Weight">14008</xsl:when>			
			<xsl:when test="$MeasurementType = $XRay">14008</xsl:when>			
			<xsl:when test="$MeasurementType = $Ratio">14054</xsl:when>	
			<xsl:when test="$MeasurementType = $FiberOrientationAngle">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_FiberOrientationTop">14028</xsl:when>
					<xsl:when test="$SensorType = $S_FiberOrientationBottom">14028</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $FiberOrientationRatio">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_FiberOrientationTop">14034</xsl:when>
					<xsl:when test="$SensorType = $S_FiberOrientationBottom">14030</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $IRCWClay">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_IRCoatWeightTop">14074</xsl:when>
					<xsl:when test="$SensorType = $S_IRCoatWeightBottom">14076</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $IRCWChalk">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_IRCoatWeightTop">14070</xsl:when>
					<xsl:when test="$SensorType = $S_IRCoatWeightBottom">14072</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $IRCWLatex">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_IRCoatWeightTop">14078</xsl:when>
					<xsl:when test="$SensorType = $S_IRCoatWeightBottom">14080</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $IRCoatMoisture">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_IRCoatWeightTop">14082</xsl:when>
					<xsl:when test="$SensorType = $S_IRCoatWeightBottom">14084</xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$MeasurementType = $CalcMeas">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_CoatWeight">
						<xsl:choose>
							<xsl:when test="@CoatType = $CT_Default">
								<xsl:value-of select="($FrameBaseLine + 4)"/>
							</xsl:when>
							<xsl:when test="@CoatType = $CT_BasisWeightDifference">
								<xsl:value-of select="($FrameBaseLine + 2)"/>
							</xsl:when>
							<xsl:when test="@CoatType = $CT_DryWeightDifference">
								<xsl:value-of select="($FrameBaseLine + 4)"/>
							</xsl:when>
							<xsl:when test="@CoatType = $CT_XrayWeightDifference">
								<xsl:value-of select="($FrameBaseLine + 6)"/>
							</xsl:when>
							<xsl:when test="@CoatType = $CT_IRSingleCoat">
								<xsl:value-of select="($FrameBaseLine + 8)"/>
							</xsl:when>
							<xsl:when test="@CoatType = $CT_IRDualCoat">
								<xsl:value-of select="($FrameBaseLine + 10)"/>
							</xsl:when>
							<!-- could have up to 2 press coat meas -->
							<xsl:when test="@CoatType = $CT_IRPressCoat">
								<xsl:value-of select="($FrameBaseLine + ((count(preceding-sibling::*[@CoatType = $CT_IRPressCoat]) * 2) + 12) ) "/>
							</xsl:when>
						</xsl:choose>
					</xsl:when>
					<xsl:when test="$SensorType = $S_WaterBalance">
						<xsl:value-of select="($FrameBaseLine + 18)"/>
					</xsl:when>
					<xsl:when test="$SensorType = $S_TissueWeight">
						<xsl:value-of select="($FrameBaseLine + 16)"/>
					</xsl:when>
					<!-- could have up to 5 unique cal meas -->
					<xsl:when test="$SensorType = $S_UniqueCalcMeas">
						<xsl:value-of select="($FrameBaseLine + ((count(preceding-sibling::*[@SensorType = $S_UniqueCalcMeas]) * 2) + 22) ) "/>
					</xsl:when>
					<!-- could have up to 5 profile difference meas -->
					<xsl:when test="$SensorType = $S_Difference">
						<xsl:value-of select="($FrameBaseLine + ((count(preceding-sibling::*[@SensorType = $S_Difference]) * 2) + 32) ) "/>
					</xsl:when>
					<xsl:when test="$SensorType = $S_TwistIndex">
						<xsl:value-of select="($FrameBaseLine + 42)"/>
					</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $HiddenCalcMeas">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_WeightCompensatedMoisture">
						<xsl:value-of select="($FrameBaseLine + 20)"/>
					</xsl:when>
				</xsl:choose>
			</xsl:when>	
			<!-- Unknown -->
			<xsl:otherwise>????</xsl:otherwise> 
		</xsl:choose>
	</xsl:template>
	

	<!-- *********************************************************************************************************************
		MeasDependPriority
		
		Returns Measurement Dependency Priority for Measurement Type
		1	= Independent
		2	= First Order Dependent
		.
		.
		n	= N'th Order Dependent
		
		Measurement entries in Startup.xml are order dependent.  Dependent measurements must
		follow independent measurements.
		*********************************************************************************************************************	
	-->
	<xsl:template name="MeasDependPriority">
		<xsl:param name="SensorType"/>
		<xsl:param name="MeasurementType"/>
		<xsl:choose>
			<xsl:when test="$MeasurementType = $AirColumn">1</xsl:when>
			<xsl:when test="$MeasurementType = $ApparentDensity">1</xsl:when>
			<xsl:when test="$MeasurementType = $Ash">1</xsl:when>
			<xsl:when test="$MeasurementType = $Brightness">1</xsl:when>
			<xsl:when test="$MeasurementType = $Caliper">1</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliper">1</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperMA">1</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperOP">1</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperCD">1</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperMD">1</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperZD">1</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperRO">1</xsl:when>	
			<xsl:when test="$MeasurementType = $SurfacePropertiesMaV">1</xsl:when>
			<xsl:when test="$MeasurementType = $SurfacePropertiesMiV">1</xsl:when>
	
			<xsl:when test="$MeasurementType = $Color">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_ColorTop">2</xsl:when>
					<xsl:when test="$SensorType = $S_ColorBottom">2</xsl:when>
				</xsl:choose>
			</xsl:when>	
			<xsl:when test="$MeasurementType = $ConditionedWeight">2</xsl:when>			
			<xsl:when test="$MeasurementType = $Formation">1</xsl:when>	
			<xsl:when test="$MeasurementType = $Gloss">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_GlossTop">1</xsl:when>
					<xsl:when test="$SensorType = $S_GlossBottom">1</xsl:when>
				</xsl:choose>
			</xsl:when>	
			<xsl:when test="$MeasurementType = $Moisture">1</xsl:when>			
			<xsl:when test="$MeasurementType = $MicrowaveMoisture">1</xsl:when>			
			<xsl:when test="$MeasurementType = $HPIRTMoisture">1</xsl:when>	
			<xsl:when test="$MeasurementType = $HPIRRMoisture">1</xsl:when>	
			<xsl:when test="$MeasurementType = $HPIRBWMoisture">1</xsl:when>
			<xsl:when test="$MeasurementType = $HPIRBWFiberWeight">1</xsl:when>
			<xsl:when test="$MeasurementType = $HPIRBWBasisWeight">1</xsl:when>
			<xsl:when test="$MeasurementType = $Opacity">1</xsl:when>			
			<xsl:when test="$MeasurementType = $Temperature">1</xsl:when>			
			<xsl:when test="$MeasurementType = $Unique">1</xsl:when>	
			<xsl:when test="$MeasurementType = $Weight">1</xsl:when>			
			<xsl:when test="$MeasurementType = $XRay">1</xsl:when>			
			<xsl:when test="$MeasurementType = $Ratio">1</xsl:when>	
			<xsl:when test="$MeasurementType = $FiberOrientationAngle">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_FiberOrientationTop">1</xsl:when>
					<xsl:when test="$SensorType = $S_FiberOrientationBottom">1</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $FiberOrientationRatio">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_FiberOrientationTop">1</xsl:when>
					<xsl:when test="$SensorType = $S_FiberOrientationBottom">1</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $IRCWClay">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_IRCoatWeightTop">1</xsl:when>
					<xsl:when test="$SensorType = $S_IRCoatWeightBottom">1</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $IRCWChalk">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_IRCoatWeightTop">1</xsl:when>
					<xsl:when test="$SensorType = $S_IRCoatWeightBottom">1</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $IRCWLatex">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_IRCoatWeightTop">1</xsl:when>
					<xsl:when test="$SensorType = $S_IRCoatWeightBottom">1</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $IRCoatMoisture">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_IRCoatWeightTop">1</xsl:when>
					<xsl:when test="$SensorType = $S_IRCoatWeightBottom">1</xsl:when>
				</xsl:choose>
			</xsl:when>						
			<xsl:when test="$MeasurementType = $CalcMeas">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_CoatWeight">2</xsl:when>
					<xsl:when test="$SensorType = $S_WaterBalance">2</xsl:when>
					<xsl:when test="$SensorType = $S_TissueWeight">2</xsl:when>
					<xsl:when test="$SensorType = $S_UniqueCalcMeas">2</xsl:when>
					<xsl:when test="$SensorType = $S_Difference">2</xsl:when>
					<xsl:when test="$SensorType = $S_TwistIndex">2</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $HiddenCalcMeas">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_WeightCompensatedMoisture">2</xsl:when>
				</xsl:choose>
			</xsl:when>
			<!-- External MD -->
			<xsl:when test="$MeasurementType = $ExternalMD">1</xsl:when>
			<!-- Unknown -->
			<xsl:otherwise>0</xsl:otherwise> 
		</xsl:choose>
	</xsl:template>


	<!-- 	*********************************************************************************************************************
		MeasName
		
		Returns translated Measurement Name for sensor and measurement types passed as parameters
		*********************************************************************************************************************	
	-->
	<xsl:template name="MeasName">
		<xsl:param name="SensorType"/>
		<xsl:param name="MeasurementType"/>
		<xsl:choose>
			<xsl:when test="$MeasurementType = $AirColumn">Air Column</xsl:when>
			<xsl:when test="$MeasurementType = $ApparentDensity">Apparent Density</xsl:when>
			<xsl:when test="$MeasurementType = $Ash">Ash</xsl:when>
			<xsl:when test="$MeasurementType = $Brightness">Brightness</xsl:when>
			<xsl:when test="$MeasurementType = $Caliper">Caliper</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliper">Optical Caliper</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperMA">Optical Caliper Magnetic Measurement</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperOP">Optical Caliper Optic Measurement</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperCD">Optical Caliper CD Measurement</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperMD">Optical Caliper MD Measurement</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperZD">Optical Caliper Z Measurement</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperRO">Optical Caliper Roughness Measurement</xsl:when>	
			<xsl:when test="$MeasurementType = $SurfacePropertiesMaV">Surface Properties Macro</xsl:when>
			<xsl:when test="$MeasurementType = $SurfacePropertiesMiV">Surface Properties Micro</xsl:when>
			<xsl:when test="$MeasurementType = $Color">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_ColorTop">Color Top</xsl:when>
					<xsl:when test="$SensorType = $S_ColorBottom">Color Bottom</xsl:when>
				</xsl:choose>
			</xsl:when>	
			<xsl:when test="$MeasurementType = $ConditionedWeight">Conditioned Weight</xsl:when>			
			<xsl:when test="$MeasurementType = $Formation">Formation</xsl:when>	
			<xsl:when test="$MeasurementType = $Gloss">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_GlossTop">Gloss Top</xsl:when>
					<xsl:when test="$SensorType = $S_GlossBottom">Gloss Bottom</xsl:when>
				</xsl:choose>
			</xsl:when>	
			<xsl:when test="$MeasurementType = $Moisture">Moisture IR</xsl:when>			
			<xsl:when test="$MeasurementType = $MicrowaveMoisture">Microwave Moisture</xsl:when>			
			<xsl:when test="$MeasurementType = $HPIRTMoisture">HPIR-T Moisture</xsl:when>
			<xsl:when test="$MeasurementType = $HPIRRMoisture">HPIR-R Moisture</xsl:when>
			<xsl:when test="$MeasurementType = $HPIRBWMoisture">HPIR-BW Moisture</xsl:when>
			<xsl:when test="$MeasurementType = $HPIRBWFiberWeight">HPIR-BW Fiber Weight</xsl:when>
			<xsl:when test="$MeasurementType = $HPIRBWBasisWeight">HPIR-BW Basis Weight</xsl:when>
			<xsl:when test="$MeasurementType = $Opacity">Opacity</xsl:when>			
			<xsl:when test="$MeasurementType = $Temperature">Sheet Temperature</xsl:when>			
			<xsl:when test="$MeasurementType = $Unique">Unique Sensor</xsl:when>	
			<xsl:when test="$MeasurementType = $Weight">Basis Weight</xsl:when>			
			<xsl:when test="$MeasurementType = $XRay">X-Ray</xsl:when>			
			<xsl:when test="$MeasurementType = $Ratio">Ratio</xsl:when>	
			<xsl:when test="$MeasurementType = $FiberOrientationAngle">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_FiberOrientationTop">Fiber Orientation</xsl:when>
					<xsl:when test="$SensorType = $S_FiberOrientationBottom">Fiber Orientation</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $FiberOrientationRatio">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_FiberOrientationTop">Fiber Orientation</xsl:when>
					<xsl:when test="$SensorType = $S_FiberOrientationBottom">Fiber Orientation</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $IRCWClay">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_IRCoatWeightTop">IR Coat Weight Clay</xsl:when>
					<xsl:when test="$SensorType = $S_IRCoatWeightBottom">IR Coat Weight Clay</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $IRCWChalk">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_IRCoatWeightTop">IR Coat Weight Chalk</xsl:when>
					<xsl:when test="$SensorType = $S_IRCoatWeightBottom">IR Coat Weight Chalk</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $IRCWLatex">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_IRCoatWeightTop">IR Coat Weight Latex</xsl:when>
					<xsl:when test="$SensorType = $S_IRCoatWeightBottom">IR Coat Weight Latex</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $IRCoatMoisture">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_IRCoatWeightTop">IR Coat Moisture</xsl:when>
					<xsl:when test="$SensorType = $S_IRCoatWeightBottom">IR Coat Moisture</xsl:when>
				</xsl:choose>
			</xsl:when>						
			<xsl:when test="$MeasurementType = $CalcMeas">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_CoatWeight">Coat Weight</xsl:when>
					<xsl:when test="$SensorType = $S_WaterBalance">Water Balance</xsl:when>
					<xsl:when test="$SensorType = $S_TissueWeight">Tissue Weight</xsl:when>
					<xsl:when test="$SensorType = $S_UniqueCalcMeas">Unique Calculated Measurement</xsl:when>
					<xsl:when test="$SensorType = $S_Difference">Difference</xsl:when>
					<xsl:when test="$SensorType = $S_TwistIndex">Twist Index</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $HiddenCalcMeas">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_WeightCompensatedMoisture">Weight Compensated Moisture</xsl:when>
				</xsl:choose>
			</xsl:when>	
			<xsl:when test="$MeasurementType = $HPColor">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_HPColorTop">HP Color Top</xsl:when>
					<xsl:when test="$SensorType = $S_HPColorBottom">HP Color Bottom</xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$MeasurementType = $HPColorProfileaStar">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_HPColorProfileTop">HP Color Top a star</xsl:when>
					<xsl:when test="$SensorType = $S_HPColorProfileBottom">HP Color Bottom a star</xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$MeasurementType = $HPColorProfilebStar">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_HPColorProfileTop">HP Color Top b star</xsl:when>
					<xsl:when test="$SensorType = $S_HPColorProfileBottom">HP Color Bottom b star</xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$MeasurementType = $HPColorProfileLStar">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_HPColorProfileTop">HP Color Top L star</xsl:when>
					<xsl:when test="$SensorType = $S_HPColorProfileBottom">HP Color Bottom L star</xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$MeasurementType = $HPColorProfileBrightness">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_HPColorProfileTop">HP Color Top Brightness</xsl:when>
					<xsl:when test="$SensorType = $S_HPColorProfileBottom">HP Color Bottom Brightness</xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$MeasurementType = $HPColorProfileUVBrightness">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_HPColorProfileTop">HP Color Top UV Brightness</xsl:when>
					<xsl:when test="$SensorType = $S_HPColorProfileBottom">HP Color Bottom UV Brightness</xsl:when>
				</xsl:choose>
			</xsl:when>
			<!-- External MD -->
			<xsl:when test="$MeasurementType = $ExternalMD">External MD Measurement</xsl:when>
			<!-- Unknown -->
			<xsl:otherwise>Unknown Measurement</xsl:otherwise> 
		</xsl:choose>
	</xsl:template>
	
	<!--	*********************************************************************************************************************
		MeasObject
		
		Returns untranslated Measurement Name for sensor and measurement types passed as parameters
		*********************************************************************************************************************	
	-->
	<xsl:template name="MeasObject">
		<xsl:param name="SensorType"/>
		<xsl:param name="MeasurementType"/>
		<xsl:choose>
			<xsl:when test="$MeasurementType = $AirColumn">AirColumn</xsl:when>
			<xsl:when test="$MeasurementType = $ApparentDensity">ApparentDensity</xsl:when>
			<xsl:when test="$MeasurementType = $Ash">Ash</xsl:when>
			<xsl:when test="$MeasurementType = $Brightness">Brightness</xsl:when>
			<xsl:when test="$MeasurementType = $Caliper">Caliper</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliper">OpticalCaliper</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperMA">OpticalCaliperMagneticMeasurement</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperOP">OpticalCaliperOpticMeasurement</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperCD">OpticalCaliperCDMeasurement</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperMD">OpticalCaliperMDMeasurement</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperZD">OpticalCaliperZMeasurement</xsl:when>
			<xsl:when test="$MeasurementType = $OpticalCaliperRO">OpticalCaliperRoughnessMeasurement</xsl:when>	
			<xsl:when test="$MeasurementType = $SurfacePropertiesMaV">SurfacePropertiesMaV</xsl:when>
			<xsl:when test="$MeasurementType = $SurfacePropertiesMiV">SurfacePropertiesMiV</xsl:when>			
			<xsl:when test="$MeasurementType = $Color">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_ColorTop">ColorTop</xsl:when>
					<xsl:when test="$SensorType = $S_ColorBottom">ColorBottom</xsl:when>
				</xsl:choose>
			</xsl:when>	
			<xsl:when test="$MeasurementType = $ConditionedWeight">ConditionedWeight</xsl:when>			
			<xsl:when test="$MeasurementType = $Formation">Formation</xsl:when>	
			<xsl:when test="$MeasurementType = $Gloss">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_GlossTop">GlossTop</xsl:when>
					<xsl:when test="$SensorType = $S_GlossBottom">GlossBottom</xsl:when>
				</xsl:choose>
			</xsl:when>	
			<xsl:when test="$MeasurementType = $Moisture">Moisture</xsl:when>			
			<xsl:when test="$MeasurementType = $MicrowaveMoisture">MicrowaveMoisture</xsl:when>			
			<xsl:when test="$MeasurementType = $HPIRTMoisture">HPIRTMoisture</xsl:when>
			<xsl:when test="$MeasurementType = $HPIRRMoisture">HPIRRMoisture</xsl:when>
			<xsl:when test="$MeasurementType = $HPIRBWMoisture">HPIRBWMoisture</xsl:when>
			<xsl:when test="$MeasurementType = $HPIRBWFiberWeight">HPIRBWFiberWeight</xsl:when>
			<xsl:when test="$MeasurementType = $HPIRBWBasisWeight">HPIRBWBasisWeight</xsl:when>
			<xsl:when test="$MeasurementType = $Opacity">Opacity</xsl:when>			
			<xsl:when test="$MeasurementType = $Temperature">Temperature</xsl:when>			
			<xsl:when test="$MeasurementType = $Unique">UniqueSensor</xsl:when>	
			<xsl:when test="$MeasurementType = $Weight">BasisWeight</xsl:when>			
			<xsl:when test="$MeasurementType = $XRay">XRay</xsl:when>			
			<xsl:when test="$MeasurementType = $Ratio">Ratio</xsl:when>	
			<xsl:when test="$MeasurementType = $FiberOrientationAngle">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_FiberOrientationTop">FiberOrientationAngleTop</xsl:when>
					<xsl:when test="$SensorType = $S_FiberOrientationBottom">FiberOrientationAngleBottom</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $FiberOrientationRatio">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_FiberOrientationTop">FiberOrientationRatioTop</xsl:when>
					<xsl:when test="$SensorType = $S_FiberOrientationBottom">FiberOrientationRatioBottom</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $IRCWClay">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_IRCoatWeightTop">IRCoatWeightClayTop</xsl:when>
					<xsl:when test="$SensorType = $S_IRCoatWeightBottom">IRCoatWeightClayBottom</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $IRCWChalk">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_IRCoatWeightTop">IRCoatWeightChalkTop</xsl:when>
					<xsl:when test="$SensorType = $S_IRCoatWeightBottom">IRCoatWeightChalkBottom</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $IRCWLatex">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_IRCoatWeightTop">IRCoatWeightLatexTop</xsl:when>
					<xsl:when test="$SensorType = $S_IRCoatWeightBottom">IRCoatWeightLatexBottom</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $IRCoatMoisture">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_IRCoatWeightTop">IRCoatMoistureTop</xsl:when>
					<xsl:when test="$SensorType = $S_IRCoatWeightBottom">IRCoatMoistureBottom</xsl:when>
				</xsl:choose>
			</xsl:when>						
			<xsl:when test="$MeasurementType = $CalcMeas">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_CoatWeight">CoatWeight</xsl:when>
					<xsl:when test="$SensorType = $S_WaterBalance">WaterBalance</xsl:when>
					<xsl:when test="$SensorType = $S_TissueWeight">TissueWeight</xsl:when>
					<xsl:when test="$SensorType = $S_UniqueCalcMeas">UniqueCalculatedMeasurement</xsl:when>
					<xsl:when test="$SensorType = $S_Difference">Difference</xsl:when>
					<xsl:when test="$SensorType = $S_TwistIndex">TwistIndex</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $HiddenCalcMeas">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_WeightCompensatedMoisture">WeightCompensatedMoisture</xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$MeasurementType = $HPColor">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_HPColorTop">ColorTop</xsl:when>
					<xsl:when test="$SensorType = $S_HPColorBottom">ColorBottom</xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$MeasurementType = $HPColorProfileaStar">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_HPColorProfileTop">HPColorTopastar</xsl:when>
					<xsl:when test="$SensorType = $S_HPColorProfileBottom">HPColorBottomastar</xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$MeasurementType = $HPColorProfilebStar">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_HPColorProfileTop">HPColorTopbstar</xsl:when>
					<xsl:when test="$SensorType = $S_HPColorProfileBottom">HPColorBottombstar</xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$MeasurementType = $HPColorProfileLStar">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_HPColorProfileTop">HPColorTopLstar</xsl:when>
					<xsl:when test="$SensorType = $S_HPColorProfileBottom">HPColorBottomLstar</xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$MeasurementType = $HPColorProfileBrightness">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_HPColorProfileTop">HPColorTopBrigtness</xsl:when>
					<xsl:when test="$SensorType = $S_HPColorProfileBottom">HPColorBottomBrigtness</xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$MeasurementType = $HPColorProfileUVBrightness">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_HPColorProfileTop">HPColorTopUVBrightness</xsl:when>
					<xsl:when test="$SensorType = $S_HPColorProfileBottom">HPColorBottomUVBrightness</xsl:when>
				</xsl:choose>
			</xsl:when>
			<!-- External MD -->
			<xsl:when test="$MeasurementType = $ExternalMD">ExternalMDMeasurement</xsl:when>
			<!-- Unknown -->
			<xsl:otherwise>UnknownMeasurement</xsl:otherwise> 
		</xsl:choose>
	</xsl:template>
	
	<!-- *********************************************************************************************************************
		SP_OPCSensorDeviceID
		
		Returns measurement OPCSensorID for use by SWS displays
		*********************************************************************************************************************	
	-->
	<xsl:template name="SP_OPCSensorDeviceID">
		<xsl:param name="SensorType"/>
		<xsl:param name="MeasurementType"/>
		<xsl:param name="Nickname"/>
		<xsl:choose>
			<xsl:when test="$MeasurementType = $IRCWClay">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_IRCoatWeightTop">CWTY</xsl:when>
					<xsl:when test="$SensorType = $S_IRCoatWeightBottom">CWBY</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $IRCoatMoisture">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_IRCoatWeightTop">CWTM</xsl:when>
					<xsl:when test="$SensorType = $S_IRCoatWeightBottom">CWBM</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $IRCWChalk">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_IRCoatWeightTop">CWTK</xsl:when>
					<xsl:when test="$SensorType = $S_IRCoatWeightBottom">CWBK</xsl:when>
				</xsl:choose>
			</xsl:when>			
			<xsl:when test="$MeasurementType = $IRCWLatex">
				<xsl:choose>
					<xsl:when test="$SensorType = $S_IRCoatWeightTop">CWTL</xsl:when>
					<xsl:when test="$SensorType = $S_IRCoatWeightBottom">CWBL</xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$Nickname"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>


	<!--	*********************************************************************************************************************
		Add Measurement - not even being called now
		
		Adds measurement element to joconfig.xml
		*********************************************************************************************************************	
	-->
	<xsl:template name="AddMeasurement">
		<xsl:param name="MeasNumber" select="1"/>
		<xsl:param name="MeasTypeID"/>
		<xsl:param name="MeasID"/>
		<xsl:param name="MeasDesc"/>
		<xsl:param name="MeasDepPriority" select="1"/>
		<xsl:param name="SensorTypeID" select="0"/>
		
		<xsl:element name="{name()}">
			<xsl:variable name="typeID">
				<xsl:value-of select="$MeasTypeID"/>
			</xsl:variable>
			<xsl:for-each select="@*">
				<xsl:variable name="attnm">
					<xsl:value-of select="name()"/>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="($attnm='MeasurementID')">
						<xsl:attribute name="{name()}"><xsl:value-of select="$MeasID"/></xsl:attribute>
					</xsl:when>
					<xsl:when test="($attnm='MeasurementTypeID')">
						<xsl:attribute name="{name()}"><xsl:value-of select="$typeID"/></xsl:attribute>
					</xsl:when>
					<xsl:when test="($attnm='Description')">
						<xsl:attribute name="{name()}"><xsl:value-of select="$MeasDesc"/></xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="{name()}"><xsl:value-of select="."/></xsl:attribute>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
	
			<xsl:variable name="nickname">
				<xsl:call-template name="SP_Nickname">
					<xsl:with-param name="SensorType">
						<xsl:value-of select="$SensorTypeID"/>
					</xsl:with-param>
					<xsl:with-param name="MeasurementType">
						<xsl:value-of select="$typeID"/>
					</xsl:with-param>
					<xsl:with-param name="MeasurementNumber">
						<xsl:value-of select="'$MeasNumber'"/>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:variable>
			<xsl:variable name="objname">
				<xsl:call-template name="MeasObject">
					<xsl:with-param name="SensorType">
						<xsl:value-of select="$SensorTypeID"/>
					</xsl:with-param>
					<xsl:with-param name="MeasurementType">
						<xsl:value-of select="$typeID"/>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:variable>
					
			<!-- measurement dependency priority, 1 = independent, n = n'th order dependent -->
			<xsl:variable name="depprior">
				<xsl:call-template name="MeasDependPriority">
					<xsl:with-param name="SensorType">
						<xsl:value-of select="$SensorTypeID"/>
					</xsl:with-param>
					<xsl:with-param name="MeasurementType">
						<xsl:value-of select="$typeID"/>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:variable>

			<xsl:variable name="ctrlname">
				<xsl:call-template name="MeasCtrlName">
					<xsl:with-param name="SensorType">
						<xsl:value-of select="$SensorTypeID"/>
					</xsl:with-param>
					<xsl:with-param name="MeasurementType">
						<xsl:value-of select="$typeID"/>
					</xsl:with-param>
					<xsl:with-param name="ScannerNumber">
						<xsl:value-of select="../@ScannerNumber"/>
					</xsl:with-param>
					<xsl:with-param name="MeasurementNumber">
						<xsl:value-of select="$MeasNumber"/>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:variable>
			
			<xsl:attribute name="MeasName"><xsl:value-of select="$ctrlname"/></xsl:attribute>
			<xsl:attribute name="oNum"><xsl:value-of select="$MeasNumber"/></xsl:attribute>
			<xsl:attribute name="oName"><xsl:value-of select="$nickname"/></xsl:attribute>
			<xsl:attribute name="DependPriority"><xsl:value-of select="$depprior"/></xsl:attribute>
			<xsl:attribute name="OID"><xsl:value-of select="concat($objname, '_', ../@ScannerNumber)"/></xsl:attribute>
			<xsl:attribute name="TLName"><xsl:value-of select="$objname"/></xsl:attribute>
		</xsl:element>
	</xsl:template>
	
</xsl:stylesheet>
