@echo off
REM ****************************************************************************
REM *
REM * =========
REM * START.bat
REM * =========
REM *
REM * Arguments:
REM *
REM * %1 = path to volume CMDS. Path is found in the file
REM *      %DXBASE_HOME%\SystemModules\RTA\volumes.fil.
REM *      See example in "Abstract".
REM * %2 = network number
REM * %3 = node number. The combination of %2 and %3 is the node
REM *      where command file given as %4 will be executed.
REM * %4 = Advant Master command file to execute in Advant Master node.
REM * %5 = timeout in seconds for dxCommand.
REM *
REM * Abstract:
REM *
REM *      This script file executes an Advant Master command file.
REM *      It's assumed that the command file executes the HEALTH command.
REM *      Exit code from the script different from 0 means that dxCommand 
REM *      failed. This file should always be executed in an 800xA Advant
REM *      Master Connectivity server.
REM *
REM *      ===============================================
REM *      Example of contents of volume file volumes.fil
REM *      ===============================================
REM *
REM *      2 INIT C:\ProgramData\ABB\AC400Connect\AdvantBase\Data\RTA\INIT
REM *      3 DUMP C:\ProgramData\ABB\AC400Connect\AdvantBase\Data\RTA\DUMP
REM *      4 LOGG C:\ProgramData\ABB\AC400Connect\AdvantBase\Data\RTA\LOGG
REM *      8 CMDS C:\ProgramData\ABB\AC400Connect\AdvantBase\Data\RTA\CMDS
REM *
REM *      The normal way of using the HEALTH command processor is
REM *      as follows:
REM *
REM *      1) Run this bat file with network and node number set to 0
REM *         (execute in local RTA) and a command file (%2) containing the line:
REM *         HEALTH GETNODES,LOGG,NODES.IN.
REM *         It will produce a Windows INI file, NODES.IN in the folder pointed out
REM *         by volume LOGG. The file contains all currently reachable nodes.
REM *
REM *      2) Run this bat file once per connected node. The command file (%2) 
REM *         contains the line:
REM *         HEALTH START,,,
REM *         It will start task load and channel utilization measurement in the
REM *         node specified by arguments network (%2) and node (%3).
REM *
REM *      3) Wait approx. 10 - 20 minutes.
REM *
REM *      4) Run this bat file once per connected node. The command file (%2)
REM *         contains the line:
REM *         HEALTH STOP,LOGG,"network""node".IN,5
REM *         
REM *         The HEALTH command will stop task load and channel
REM *         utilization measurements and system messages will
REM *         be collected for 5 minutes (last command parameter).
REM *         Min and max values of system load will be saved during
REM *         the time the command is executing. Signal transmission
REM *         statistics for signals to Controllers and to Windows
REM *         via the dual port memory are fetched from the task 
REM *         parameter area for all tsk instance numbers of the 
REM *         transmission tasks DCXA12 and DCXA13. At last is clock
REM *         synch status retreived. The following data is stored
REM *         in the file "network"node".IN when 5 minutes have elapsed:
REM *
REM Ä         - System identity
REM *         - Task load
REM *         - Channel utilization
REM *         - System load
REM *         - System messages (if any)
REM *         - Clock synchronization status
REM *         - Signal transmission statistics (if RTA)
REM *         - Free memory in system data pool
REM *         - Errors during command processor execution (if any)
REM *
REM ****************************************************************************

REM ====================================
REM Change folder to command processor 
REM and command files folder
REM ====================================
cd %1

REM ====================================================================
REM Start command file %4 which executes command processor 
REM HEALTH with action GETNODES, START or STOP 
REM The file must exist in the directory pointed out by %1.
REM 
REM Arguments: -f %4    - Advant Master command file to execute
REM            -n %2    - network number
REM            -N %3    - node number
REM            -t %5    - dxCommand timeout
REM            -S       - dxCommand will execute the command SLTARG
REM ====================================================================
"%ADVANT_PERIPHERAL_HOME%\bin\dxcommand.exe" -f %4 -n %2 -N %3 -t %5 -S

REM ===============================
REM Return exit code from dxCommand
REM ===============================
exit /b %errorlevel%